@@ -26,17 +26,22 @@
 #include "../include/mpu401.h"
 #include "../include/opl3.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: AD1816A, AD1815\n\
 Card: ADI SoundPort AD1816A\n\
 Card: ADI SoundComm AD1815\n\
 Card: Highscreen Sound-Boostar 16 3D\n\
+Card: Aztech/Newcom SC-16 3D\n\
 ISAPNP: MDK1605=ADS7180,ADS7181\n\
 ISAPNP: ADS7150=ADS7150,ADS7151\n\
 ISAPNP: ADS7181=ADS7180,ADS7181\n\
 ISAPNP: LWC1061=ADS7180,ADS7181\n\
 ISAPNP: TER1411=ADS7180,ADS7181\n\
+ISAPNP: AZT1022=AZT1018,AZT2002\n\
+ISAPNP: SMM7180=ADS7180,ADS7181\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;		/* Index 1-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;		/* ID for this card */
@@ -113,13 +118,21 @@ static unsigned int snd_card_ad1816a_pnpids[] = {
 	(ISAPNP_VENDOR('T','E','R')<<16)|ISAPNP_DEVICE(0x1411),    /* device */
 	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_FUNCTION(0x7180),  /* audio */
 	(ISAPNP_VENDOR('A','D','S')<<16)|ISAPNP_FUNCTION(0x7181),  /* mpu401 */
+	/* Analog Devices AD1816A - Aztech/Newcom SC-16 3D */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_DEVICE(0x1022),    /* device */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x1018),  /* audio */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x2002),  /* mpu401 */
+	/* Shark Predator ISA */
+	(ISAPNP_VENDOR('S','M','M')<<16)|ISAPNP_DEVICE(0x7180),    /* device */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x7180),  /* audio */
+	(ISAPNP_VENDOR('A','Z','T')<<16)|ISAPNP_FUNCTION(0x7181),  /* mpu401 */
 	0	/* end */
 };
 #endif	/* __ISAPNP__ */
 
 #define	DRIVER_NAME	"snd-card-ad1816a"
 
-#define snd_card_ad1816a_printk(args...)	snd_printk(__FILE__": " ##args)
+#define snd_card_ad1816a_printk(format, args...) snd_printk(__FILE__": " format, ##args)
 
 
 static void snd_card_ad1816a_use_inc(snd_card_t *card)
