@@ -33,11 +33,13 @@
 #define CARD_NAME "CS4281"
 #define DRIVER_NAME "CS4281"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: Cirrus Logic CS4281\n\
 Card: Cirrus Logic CS4281 PCI\n\
-PCI: 0x1274=0x5000\n\
+PCI: 0x1013=0x6005\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
@@ -462,16 +464,16 @@ static struct pci_device_id snd_cs4281_ids[] __devinitdata = {
 
 MODULE_DEVICE_TABLE(pci, snd_cs4281_ids);
 
-inline static int snd_dma_size(int size, int min, int max)
+inline static unsigned long snd_dma_size(int size, int min, int max)
 {
 	if (size < min) {
 		snd_printk("too small dma size %d, using %d\n", size, min);
-		return min;
+		size = min;
 	} else if (size > max) {
 		snd_printk("too large dma size %d, using %d\n", size, max);
-		return max;
-	} else
-		return size;
+		size = max;
+	}
+	return (unsigned long)size * 1024;
 }
 
 static void snd_cs4281_use_inc(snd_card_t *card)
@@ -1116,11 +1118,13 @@ static int __init snd_cs4281_create(snd_card_t * card,
 	}
 	if ((err = snd_register_dma_channel(card,
 					    "CS4281 - DAC frame", 0,
-					    SND_DMA_TYPE_PCI, play_dma_size,
+					    SND_DMA_TYPE_PCI,
+					    play_dma_size / 1024,
 					    NULL, &chip->dma_dac)) < 0 ||
 	    (err = snd_register_dma_channel(card,
 					    "CS4281 - ADC frame", 0,
-					    SND_DMA_TYPE_PCI, capt_dma_size,
+					    SND_DMA_TYPE_PCI,
+					    capt_dma_size / 1024,
 					    NULL, &chip->dma_adc)) < 0) {
 		snd_cs4281_free(chip);
 		snd_printk("cs4281: can't assign dma\n");
