@@ -24,6 +24,7 @@
 #include "../include/cs461x.h"
 #include "../include/initval.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: Cirrus Logic Sound Fusion CS461X\n\
 Card: Generic CS4280\n\
@@ -31,15 +32,21 @@ Card: Generic CS4610\n\
 Card: Generic CS4612\n\
 Card: Generic CS4614\n\
 Card: Generic CS4615\n\
+Card: Generic CS4622\n\
+Card: Generic CS4624\n\
+Card: Generic CS4630\n\
 PCI: 0x1013=0x6001\n\
 PCI: 0x1013=0x6003\n\
 PCI: 0x1013=0x6004\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
 int snd_dac_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
 int snd_adc_frame_size[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 128};
+int snd_external_amp[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0};
+int snd_thinkpad[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0};
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_index, "Index value for the CS461x soundcard.");
 MODULE_PARM(snd_id, "1-" __MODULE_STRING(SND_CARDS) "s");
@@ -48,6 +55,10 @@ MODULE_PARM(snd_dac_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_dac_frame_size, "DAC frame size in kB for the CS461x soundcard.");
 MODULE_PARM(snd_adc_frame_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_adc_frame_size, "ADC frame size in kB for the CS461x soundcard.");
+MODULE_PARM(snd_external_amp, "1-" __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM_DESC(snd_external_amp, "Force to enable external amplifer.");
+MODULE_PARM(snd_thinkpad, "1-" __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM_DESC(snd_thinkpad, "Force to enable Thinkpad's CLKRUN control.");
 
 struct snd_cs461x {
 	struct pci_dev *pci;
@@ -165,6 +176,7 @@ static int __init snd_card_cs461x_probe(int dev, struct snd_cs461x *scard)
 			      scard->dma1ptr,
 			      scard->dma2ptr,
 			      scard->irqptr,
+			      snd_external_amp[dev], snd_thinkpad[dev],
 			      &scard->codec) < 0)
 		goto __nodev;
 	if (snd_cs461x_pcm(scard->codec, 0, &pcm) < 0)
