@@ -26,10 +26,12 @@
 #include "../include/rawmidi.h"
 #include "../include/initval.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\n\
 Driver: Dummy soundcard (/dev/null)\n\
 ALWAYS\n\
 ");
+MODULE_LICENSE("GPL");
 
 #define MAX_PCM_DEVICES		4
 #define MAX_PCM_SUBCHANNELS	16
@@ -319,7 +321,7 @@ static int snd_card_dummy_playback_open(void *private_data,
 	spin_lock_init(&dpcm->lock);
 	dpcm->subchn = subchn;
 	subchn->runtime->private_data = dpcm;
-	subchn->runtime->private_free = _snd_magic_kfree;
+	subchn->runtime->private_free = (snd_kfree_type)_snd_magic_kfree;
 	subchn->runtime->hw = &snd_card_dummy_playback;
 	return 0;
 }
@@ -343,7 +345,7 @@ static int snd_card_dummy_capture_open(void *private_data,
 	spin_lock_init(&dpcm->lock);
 	dpcm->subchn = subchn;
 	subchn->runtime->private_data = dpcm;
-	subchn->runtime->private_free = _snd_magic_kfree;
+	subchn->runtime->private_free = (snd_kfree_type)_snd_magic_kfree;
 	subchn->runtime->hw = &snd_card_dummy_capture;
 	return 0;
 }
