@@ -26,6 +26,7 @@
 #include "../include/opl3.h"
 #include "../include/initval.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: ESS AudioDrive ESx688\n\
 Card: ESS ES688 PnP AudioDrive\n\
@@ -33,6 +34,7 @@ Card: ESS ES1688 PnP AudioDrive\n\
 Card: ESS ES688 AudioDrive\n\
 Card: ESS ES1688 AudioDrive\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
@@ -143,8 +145,8 @@ static int __init snd_audiodrive_resources(int dev,
 					   struct snd_audiodrive *acard,
 					   snd_card_t * card)
 {
-	static int possible_irqs[] = {5, 9, 10, 7, -1};
-	static int possible_dmas[] = {1, 3, 0, -1};
+	static long possible_irqs[] = {5, 9, 10, 7, -1};
+	static long possible_dmas[] = {1, 3, 0, -1};
 	int err;
 
 	if ((err = snd_register_interrupt(card, "ESx688", snd_irq[dev],
@@ -237,7 +239,7 @@ static int __init snd_audiodrive_probe(int dev, struct snd_audiodrive *acard)
 		goto __nodev;
 	strcpy(card->abbreviation, "AudioDrive");
 	strcpy(card->shortname, pcm->name);
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li, dma %li",
 		pcm->name,
 		codec->port,
 		acard->irqptr->irq,
