@@ -27,6 +27,7 @@
 #include "../include/opl3.h"
 #include "../include/initval.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: ESS AudioDrive ES18xx\n\
 Card: ESS ES1868\n\
@@ -43,6 +44,7 @@ ISAPNP: ESS1869=ESS1869,ESS0006\n\
 ISAPNP: ESS1878=ESS1878,ESS0004\n\
 ISAPNP: ESS1879=ESS1879,ESS0009\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
@@ -83,7 +85,7 @@ MODULE_PARM(snd_dma2_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_dma2_size, "Size of DMA 2 # for ES18xx driver. [DMA_SIZE]");
 #ifdef __ISAPNP__
 MODULE_PARM(snd_isapnp, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for specified soundcard. [BOOL]");
+MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for ES18xx soundcard. [BOOL]");
 #endif
 
 static struct snd_audiodrive {
