@@ -26,10 +26,12 @@
 #include "../include/opl3.h"
 #include "../include/initval.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: ForteMedia FM801\n\
 PCI: 0x1319=0x0801\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
@@ -150,6 +152,10 @@ static int __init snd_card_fm801_probe(int dev, struct snd_fm801 *scard)
 		snd_card_free(card);
 		return -ENODEV;
 	}
+	if (pci_enable_device(scard->pci)) {
+		snd_card_free(card);
+		return -ENODEV;
+	}
 	if (snd_card_fm801_resources(card, scard, dev) < 0) {
 		snd_card_free(card);
 		return -ENODEV;
@@ -175,7 +181,7 @@ static int __init snd_card_fm801_probe(int dev, struct snd_fm801 *scard)
  
 	strcpy(card->abbreviation, "FM801");
 	strcpy(card->shortname, "ForteMedia FM801");
-	sprintf(card->longname, "%s at 0x%lx, irq %i",
+	sprintf(card->longname, "%s at 0x%lx, irq %li",
 		card->shortname,
 		pci_resource_start(scard->pci, 0),
 		scard->irqptr->irq);
