@@ -26,9 +26,11 @@
 #include "../include/cs4231.h"
 #include "../include/initval.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: Gravis UltraSound MAX\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
@@ -182,8 +184,8 @@ static void snd_gusmax_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 static int __init snd_gusmax_resources(int dev, struct snd_gusmax *maxcard,
 				       snd_card_t * card)
 {
-	static int possible_irqs[] = {5, 11, 12, 9, 7, 15, 3, -1};
-	static int possible_dmas[] = {5, 6, 7, 1, 3, -1};
+	static long possible_irqs[] = {5, 11, 12, 9, 7, 15, 3, -1};
+	static long possible_dmas[] = {5, 6, 7, 1, 3, -1};
 	int err;
 
 	if ((err = snd_register_interrupt(card, "GUS MAX",
@@ -376,12 +378,12 @@ static int __init snd_gusmax_probe(int dev, struct snd_gusmax *maxcard)
 #ifdef CONFIG_SND_SEQUENCER
 	snd_gus_attach_synthesizer(gus);
 #endif
-	sprintf(card->longname + strlen(card->longname), " at 0x%x, irq %i, dma %i",
+	sprintf(card->longname + strlen(card->longname), " at 0x%lx, irq %li, dma %li",
 		gus->gf1.port,
 		maxcard->irqptr->irq,
 		maxcard->dma1ptr->dma);
 	if (maxcard->dma2ptr)
-		sprintf(card->longname + strlen(card->longname), "&%i",
+		sprintf(card->longname + strlen(card->longname), "&%li",
 			maxcard->dma2ptr->dma);
 	snd_gf1_start(gus);
 	if (!snd_card_register(card)) {
