@@ -5,6 +5,8 @@
  * Based on nm256_audio.c OSS driver in linux kernel.
  * The original author of OSS nm256 driver wishes to remain anonymous,
  * so I just put my acknoledgment to him/her here.
+ * The original author's web page is found at
+ *	http://www.uglx.org/sony.html
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -40,6 +42,7 @@
 #define CARD_NAME "NeoMagic 256AV/ZX"
 #define DRIVER_NAME "NM256"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: NM256\n\
 Card: NeoMagic 256AV\n\
@@ -47,6 +50,7 @@ Card: NeoMagic 256ZX\n\
 PCI: 0x10c8=0x8005\n\
 PCI: 0x10c8=0x8006\n\
 ");
+MODULE_LICENSE("GPL");
 
 /*
  * some compile conditions.
@@ -58,8 +62,10 @@ int snd_enable[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 1}; /* all enabled */
 int snd_playback_bufsize[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 16};
 int snd_capture_bufsize[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 16};
 int snd_force_ac97[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0}; /* disabled as default */
+int snd_ignore_signature[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0}; /* disabled as default */
 int snd_buffer_top[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0}; /* not specified */
 int snd_use_cache[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0}; /* disabled */
+int snd_vaio_hack[SND_CARDS] = {[0 ... (SND_CARDS - 1)] = 0}; /* disabled */
 
 MODULE_PARM(snd_index, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_index, "Index value for " CARD_NAME " soundcard.");
@@ -73,10 +79,14 @@ MODULE_PARM(snd_capture_bufsize, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_capture_bufsize, "ADC frame size in kB for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_force_ac97, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_force_ac97, "Force to use AC97 codec for " CARD_NAME " soundcard. [BOOL]");
+MODULE_PARM(snd_ignore_signature, "1-" __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM_DESC(snd_ignore_signature, "Ignore signature search for " CARD_NAME " soundcard. [BOOL]");
 MODULE_PARM(snd_buffer_top, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_buffer_top, "Set the top address of audio buffer for " CARD_NAME " soundcard.");
 MODULE_PARM(snd_use_cache, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_use_cache, "Enable the cache for coefficient table access. [BOOL]");
+MODULE_PARM(snd_vaio_hack, "1-" __MODULE_STRING(SND_CARDS) "i");
+MODULE_PARM_DESC(snd_vaio_hack, "Enable workaround for Sony VAIO notebooks. [BOOL]");
 
 /*
  * directions
@@ -247,12 +257,11 @@ struct snd_nm256 {
 
 	struct pci_dev *pci;
 
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
 	struct pm_dev *pm_dev;
 #endif
 
 	spinlock_t reg_lock;
-
 };
 
 
@@ -283,16 +292,16 @@ static struct pci_device_id snd_nm256_ids[] __devinitdata = {
 	{0,},
 };
 
-inline static int snd_dma_size(int size, int min, int max)
+inline static unsigned long snd_dma_size(int size, int min, int max)
 {
 	if (size < min) {
 		snd_printk("too small dma size %d, using %d\n", size, min);
-		return min;
+		size = min;
 	} else if (size > max) {
 		snd_printk("too large dma size %d, using %d\n", size, max);
-		return max;
-	} else
-		return size;
+		size = max;
+	}
+	return (unsigned long)size * 1024;
 }
 
 static void snd_nm256_use_inc(snd_card_t *card)
@@ -1242,12 +1251,12 @@ snd_nm256_mixer(nm256_t *chip, int device, int pcm_count, int *pcm_devs)
  */
 
 static int __init
-snd_nm256_peek_for_sig(nm256_t *chip)
+snd_nm256_peek_for_sig(nm256_t *chip, int ignore_sig)
 {
 	/* The signature is located 1K below the end of video RAM.  */
 	char *temp;
 	/* Default buffer end is 5120 bytes below the top of RAM.  */
-	unsigned long default_value = chip->buffer_end - 0x1400;
+	unsigned long pointer_found = chip->buffer_end - 0x1400;
 	u32 sig;
 
 	temp = ioremap_nocache(chip->buffer_addr + chip->buffer_end - 0x400, 16);
@@ -1256,29 +1265,37 @@ snd_nm256_peek_for_sig(nm256_t *chip)
 		return -EBUSY;
 	}
 
-	/* Install the default value first, so we don't have to repeatedly
-	   do it if there is a problem.  */
-	chip->buffer_end = default_value;
-
 	sig = readl(temp);
 	if ((sig & NM_SIG_MASK) == NM_SIGNATURE) {
 		u32 pointer = readl(temp + 4);
 
 		/*
-		 * If it's obviously invalid, don't use it (the port already has a
-		 * suitable default value set).
+		 * If it's obviously invalid, don't use it
 		 */
-		if (pointer != 0xffffffff)
-			chip->buffer_end = pointer;
-
-		snd_printd("NM256: Found card signature in video RAM: 0x%x\n", pointer);
+		if (pointer == 0xffffffff ||
+		    pointer < chip->buffer_size ||
+		    pointer > chip->buffer_end) {
+			if (! ignore_sig) {
+				snd_printk("NM256: invalid signature found: 0x%x\n", pointer);
+				return -ENODEV;
+			}
+		} else {
+			pointer_found = pointer;
+			snd_printd("NM256: Found card signature in video RAM: 0x%x\n", pointer);
+		}
+	} else if (! ignore_sig) {
+		snd_printk("NM256: cannot find signature.  Aborted\n");
+		return -ENODEV;
 	}
 
 	iounmap(temp);
+	chip->buffer_end = pointer_found;
+
 	return 0;
 }
 
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
+
 /*
  * APM event handler, so the card is properly reinitialized after a power
  * event.
@@ -1289,7 +1306,6 @@ snd_nm256_handle_pm_event(struct pm_dev *dev, pm_request_t rqst, void *data)
 	nm256_t *chip = snd_magic_cast(nm256_t, dev->data, -ENXIO);
 	nm256_dma_t *s;
 	unsigned long flags;
-	int i;
 
 	switch (rqst) {
 	case PM_SUSPEND:
@@ -1304,19 +1320,7 @@ snd_nm256_handle_pm_event(struct pm_dev *dev, pm_request_t rqst, void *data)
 	case PM_RESUME:
 		/* Perform a full reset on the hardware */
 		snd_nm256_init_chip(chip);
-
-		/* reset ac97 */
-		snd_ac97_write_lock(chip->ac97, AC97_POWERDOWN, 0);
-		snd_ac97_write_lock(chip->ac97, AC97_RESET, 0);
-		udelay(100);
-		snd_ac97_write_lock(chip->ac97, AC97_POWERDOWN, 0);
-		snd_ac97_write_lock(chip->ac97, AC97_GENERAL_PURPOSE, 0);
-
-		snd_nm256_ac97_reset(chip, chip->ac97);
-
-		/* restore ac97 status */
-		for (i = 2; i < 0x26 ; i += 2)
-			snd_ac97_write_lock(chip->ac97, i, chip->ac97->regs[i]);
+		snd_ac97_resume(chip->ac97);
 		/* start dma */
 		spin_lock_irqsave(&chip->reg_lock, flags);
 		s = &chip->dma[NM_PLAYBACK];
@@ -1343,7 +1347,7 @@ static int snd_nm256_free(nm256_t *chip)
 	if (chip->dma[NM_CAPTURE].running)
 		snd_nm256_capture_stop(chip);
 
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
 	if (chip->pm_dev)
 		pm_unregister(chip->pm_dev);
 #endif
@@ -1374,8 +1378,9 @@ static int snd_nm256_dev_free(void *private_data)
 
 static int __init
 snd_nm256_create(snd_card_t *card, struct pci_dev *pci,
-		 int play_bufsize, int capt_bufsize,
-		 int force_load,
+		 unsigned long play_bufsize,
+		 unsigned long capt_bufsize,
+		 int force_load, int ignore_sig,
 		 u32 buffertop,
 		 int usecache,
 		 nm256_t **chip_ret)
@@ -1398,8 +1403,8 @@ snd_nm256_create(snd_card_t *card, struct pci_dev *pci,
 	chip->use_cache = usecache;
 	spin_lock_init(&chip->reg_lock);
 
-	chip->dma[0].bufsize = play_bufsize * 1024; /* in bytes */
-	chip->dma[1].bufsize = capt_bufsize * 1024; /* in bytes */
+	chip->dma[0].bufsize = play_bufsize;
+	chip->dma[1].bufsize = capt_bufsize;
 
 	/* 
 	 * The NM256 has two memory ports.  The first port is nothing
@@ -1436,8 +1441,8 @@ snd_nm256_create(snd_card_t *card, struct pci_dev *pci,
 		pval = snd_nm256_readw(chip, NM_MIXER_PRESENCE);
 		if ((pval & NM_PRESENCE_MASK) != NM_PRESENCE_VALUE) {
 			if (! force_load) {
-				snd_printk("nm256: no ac97 is found!\n");
-				snd_printk("  force the driver to load by passing in the module parameter\n");
+				snd_printk("nm256: no ac97 is found!  (mixer presence value returns: %0x)\n", pval);
+				snd_printk("  Force the driver to load by passing in the module parameter\n");
 				snd_printk("    snd_force_ac97=1\n");
 				snd_printk("  or try  sb16 or cs423x drivers instead.\n");
 				err = -ENXIO;
@@ -1472,7 +1477,7 @@ snd_nm256_create(snd_card_t *card, struct pci_dev *pci,
 		chip->buffer_end = buffertop;
 	else {
 		/* get buffer end pointer from signature */
-		if ((err = snd_nm256_peek_for_sig(chip)) < 0)
+		if ((err = snd_nm256_peek_for_sig(chip, ignore_sig)) < 0)
 			goto __error;
 	}
 
@@ -1534,7 +1539,7 @@ snd_nm256_create(snd_card_t *card, struct pci_dev *pci,
 
 	// pci_set_master(pci); /* needed? */
 	
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
 	chip->pm_dev = pm_register(PM_PCI_DEV, PM_PCI_ID(pci),
 				   snd_nm256_handle_pm_event);
 	if (chip->pm_dev)
@@ -1560,6 +1565,7 @@ static int __init snd_nm256_probe(struct pci_dev *pci,
 	snd_card_t *card;
 	nm256_t *chip;
 	int err;
+	int buffer_top;
 
 	if ((err = pci_enable_device(pci)) < 0)
 		return err;
@@ -1594,11 +1600,16 @@ static int __init snd_nm256_probe(struct pci_dev *pci,
 		return -EINVAL;
 	}
 
+	if (snd_vaio_hack[dev])
+		buffer_top = 0x25a800;	/* this avoids conflicts with XFree86 server */
+	else
+		buffer_top = snd_buffer_top[dev];
+
 	if ((err = snd_nm256_create(card, pci,
 				    snd_dma_size(snd_playback_bufsize[dev], 4, 128),
 				    snd_dma_size(snd_capture_bufsize[dev], 4, 128),
-				    snd_force_ac97[dev],
-				    snd_buffer_top[dev],
+				    snd_force_ac97[dev], snd_ignore_signature[dev],
+				    buffer_top,
 				    snd_use_cache[dev],
 				    &chip)) < 0) {
 		snd_card_free(card);
