@@ -27,16 +27,20 @@
 #include "../include/opl3.h"
 #include "../include/initval.h"
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: Yamaha OPL3SA2+\n\
 Card: generic Yamaha OPL3SA2\n\
 Card: generic Yamaha OPL3SA3\n\
 Card: Genius Sound Maker 3DX\n\
 Card: Pentium II AL440LX motherboard\n\
+Card: NeoMagic MagicWave 3DX\n\
 ISAPNP: YMH0020=YMH0021\n\
 ISAPNP: YMH0030=YMH0021\n\
+ISAPNP: NMX2200=NMX2210\n\
 ISAPNP: YMH0800=YMH0021\n\
 ");
+MODULE_LICENSE("GPL");
 
 int snd_index[SND_CARDS] = SND_DEFAULT_IDX;	/* Index 0-MAX */
 char *snd_id[SND_CARDS] = SND_DEFAULT_STR;	/* ID for this card */
@@ -78,8 +82,10 @@ MODULE_PARM(snd_dma1_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_dma1_size, "DMA1 size in kB for OPL3-SA driver. [DMA_SIZE]");
 MODULE_PARM(snd_dma2_size, "1-" __MODULE_STRING(SND_CARDS) "i");
 MODULE_PARM_DESC(snd_dma2_size, "DMA2 size in kB for OPL3-SA driver. [DMA_SIZE]");
+#ifdef __ISAPNP__
 MODULE_PARM(snd_isapnp, "1-" __MODULE_STRING(SND_CARDS) "i");
-MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for specified soundcard. [BOOL]");
+MODULE_PARM_DESC(snd_isapnp, "ISA PnP detection for OPL3-SA soundcard. [BOOL]");
+#endif
 MODULE_PARM(snd_opl3sa3_ymode, "1-" __MODULE_STRING(SND_CARDS) "i"); /* SL Added */
 MODULE_PARM_DESC(snd_opl3sa3_ymode, "Speaker size selection for 3D Enhancement mode: Desktop/Large Notebook/Small Notebook/HiFi. [list=0,1,2,3]");  /* SL Added */
 
@@ -121,6 +127,9 @@ static unsigned int snd_opl3sa_pnpids[] = {
 	/* ??? */
 	(ISAPNP_VENDOR('Y','M','H')<<16)|ISAPNP_DEVICE(0x0800),   /* DEVICE */
 	(ISAPNP_VENDOR('Y','M','H')<<16)|ISAPNP_FUNCTION(0x0021), /* all */
+	/* NeoMagic MagicWave 3DX */
+	(ISAPNP_VENDOR('N','M','X')<<16)|ISAPNP_DEVICE(0x2200),   /* DEVICE */
+	(ISAPNP_VENDOR('N','M','X')<<16)|ISAPNP_FUNCTION(0x2210), /* all */
 	/* --- */
 	0       /* end */
 };
@@ -301,8 +310,8 @@ static void snd_opl3sa_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 
 static int __init snd_opl3sa_resources(int dev, struct snd_opl3sa *oplcard, snd_card_t * card)
 {
-	static int possible_irqs[] = {-1}; /* must be specified by user */
-	static int possible_dmas[] = {-1}; /* must be specified by user */
+	static long possible_irqs[] = {-1}; /* must be specified by user */
+	static long possible_dmas[] = {-1}; /* must be specified by user */
 	int err;
 
 	if ((err = snd_register_interrupt(card,
@@ -863,9 +872,9 @@ static int __init snd_opl3sa_probe(int dev, struct snd_opl3sa *oplcard)
 	if (!snd_isapnp[dev]) {
 #endif
 		if (snd_port[dev] == SND_AUTO_PORT ||
-		    snd_wss_port[dev] == SND_AUTO_PORT ||
+		    snd_wss_port[dev] == SND_AUTO_PORT /* ||
 		    snd_fm_port[dev] == SND_AUTO_PORT ||
-		    snd_midi_port[dev] == SND_AUTO_PORT) {
+		    snd_midi_port[dev] == SND_AUTO_PORT */) {
 			snd_printk("probing for Yamaha OPL3-SA isn't supported\n");
 			snd_printk("port = 0x%x, wss_port = 0x%x, fm_port = 0x%x, midi_port = 0x%x\n",
 					   snd_port[dev],
@@ -935,13 +944,13 @@ static int __init snd_opl3sa_probe(int dev, struct snd_opl3sa *oplcard)
 					oplcard->irqptr->irq, &rmidi) < 0)
 			goto __nodev;
 	}
-	sprintf(card->longname, "%s at 0x%x, irq %i, dma %i",
+	sprintf(card->longname, "%s at 0x%x, irq %li, dma %li",
 		card->shortname,
 		oplcard->port,
 		oplcard->irqptr->irq,
 		oplcard->dma1ptr->dma);
 	if (oplcard->dma2ptr)
-		sprintf(card->longname + strlen(card->longname), "&%i",
+		sprintf(card->longname + strlen(card->longname), "&%li",
 			oplcard->dma2ptr->dma);
 
 	if (!snd_card_register(card)) {
