@@ -28,9 +28,11 @@
 #include "../include/initval.h"
 
 
+EXPORT_NO_SYMBOLS;
 MODULE_DESCRIPTION("\
 Driver: Share Card\n\
 ");
+MODULE_LICENSE("GPL");
 
 /* Another possible solution for this is to define an hacked version of 
    MODULE_PARM and to use { 'a', 'b', 'c' ... } like constructor.
@@ -644,7 +646,7 @@ static int snd_card_share_playback_open(void *private_data,
 	dpcm->subchn = subchn;
 	dpcm->pcmo = pcmo;
 	subchn->runtime->private_data = dpcm;
-	subchn->runtime->private_free = _snd_magic_kfree;
+	subchn->runtime->private_free = (snd_kfree_type)_snd_magic_kfree;
 	subchn->runtime->hw = &snd_card_share_playback;
 
 	mixer = pcmo->share->mixer;
@@ -708,7 +710,7 @@ static int snd_card_share_capture_open(void *private_data,
 	dpcm->subchn = subchn;
 	dpcm->pcmo = pcmo;
 	subchn->runtime->private_data = dpcm;
-	subchn->runtime->private_free = _snd_magic_kfree;
+	subchn->runtime->private_free = (snd_kfree_type)_snd_magic_kfree;
 	subchn->runtime->hw = &snd_card_share_capture;
 
 	mixer = pcmo->share->mixer;
@@ -841,7 +843,7 @@ static int __init snd_card_share_pcm(snd_card_share_t *share, int device,
 		pcmo->pcm_dev = pcm_dev;
 		pcmo->pcm_subchn = pcm_subchn;
 		pcm->chn[SND_PCM_CHANNEL_PLAYBACK].private_data = pcmo;
-		pcm->chn[SND_PCM_CHANNEL_PLAYBACK].private_free = _snd_magic_kfree;
+		pcm->chn[SND_PCM_CHANNEL_PLAYBACK].private_free = (snd_kfree_type)_snd_magic_kfree;
 		pcm->chn[SND_PCM_CHANNEL_PLAYBACK].open = snd_card_share_playback_open;
 		pcm->chn[SND_PCM_CHANNEL_PLAYBACK].close = snd_card_share_playback_close;
 	}
@@ -858,7 +860,7 @@ static int __init snd_card_share_pcm(snd_card_share_t *share, int device,
 		pcmo->pcm_dev = pcm_dev;
 		pcmo->pcm_subchn = pcm_subchn;
 		pcm->chn[SND_PCM_CHANNEL_CAPTURE].private_data = pcmo;
-		pcm->chn[SND_PCM_CHANNEL_CAPTURE].private_free = _snd_magic_kfree;
+		pcm->chn[SND_PCM_CHANNEL_CAPTURE].private_free = (snd_kfree_type)_snd_magic_kfree;
 		pcm->chn[SND_PCM_CHANNEL_CAPTURE].open = snd_card_share_capture_open;
 		pcm->chn[SND_PCM_CHANNEL_CAPTURE].close = snd_card_share_capture_close;
 	}
@@ -1138,7 +1140,7 @@ static int __init snd_card_share_mixer(snd_card_share_t *share, int device,
 			snd_magic_kfree(gmix);
 			goto __error;
 		}
-		group->private_free = _snd_magic_kfree;
+		group->private_free = (snd_kfree_type)_snd_magic_kfree;
 		if (pcm_parent->info_flags & SND_PCM_INFO_PLAYBACK) {
 			snd_card_share_mixer_element_t *mix;
 			mix = snd_magic_kcalloc(snd_card_share_mixer_element_t, 0, GFP_KERNEL);
@@ -1151,7 +1153,7 @@ static int __init snd_card_share_mixer(snd_card_share_t *share, int device,
 
 			if ((volume_el = snd_mixer_lib_volume1(mixer, "Playback Volume", k, SHARE_VOICES, range, snd_card_share_mixer_volume, mix)) == NULL)
 				goto __error;
-			volume_el->private_free = _snd_magic_kfree;
+			volume_el->private_free = (snd_kfree_type)_snd_magic_kfree;
 			gmix->me_out_vol = volume_el;
 			snd_card_share_mixer_volume(volume_el, 1, playback_voices);
 
@@ -1184,7 +1186,7 @@ static int __init snd_card_share_mixer(snd_card_share_t *share, int device,
 
 			if ((volume_el = snd_mixer_lib_volume1(mixer, "Capture Volume", k, SHARE_VOICES, range, snd_card_share_mixer_volume, mix)) == NULL)
 				goto __error;
-			volume_el->private_free = _snd_magic_kfree;
+			volume_el->private_free = (snd_kfree_type)_snd_magic_kfree;
 			gmix->me_in_vol = volume_el;
 			snd_card_share_mixer_volume(volume_el, 1, capture_voices);
 			
