@@ -1,8 +1,7 @@
 /*
  *  Advanced Linux Sound Architecture - ALSA - Driver
- *
- *  The interface file between the ALSA driver & the user space
- *  Copyright (c) 1994-2000 by Jaroslav Kysela <perex@suse.cz>
+ *  Copyright (c) 1994-2000 by Jaroslav Kysela <perex@suse.cz>,
+ *                             Abramo Bagnara <abramo@alsa-project.org>
  *
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -31,6 +30,8 @@
 #define SND_LITTLE_ENDIAN
 #elif __BYTE_ORDER == __BIG_ENDIAN
 #define SND_BIG_ENDIAN
+#else
+#error "Unsupported endian..."
 #endif
 #endif
 #ifndef __KERNEL__
@@ -96,33 +97,33 @@ typedef struct snd_switch_list_item {
 } snd_switch_list_item_t;
 
 typedef struct snd_switch_list {
-	int iface;			/* switch interface number */
-	int device;			/* device number */
-	int channel;			/* channel number */
-	int switches_size;		/* size of switches in array */
-	int switches;			/* filled switches in array */
-	int switches_over;		/* missing switches in array */
-	snd_switch_list_item_t *pswitches; /* pointer to list item array */
+	int iface;			/* WR: switch interface number */
+	int device;			/* WR: device number */
+	int channel;			/* WR: channel number */
+	int switches_size;		/* WR: size of switches in array */
+	int switches;			/* RO: filled switches in array */
+	int switches_over;		/* RO: missing switches in array */
+	snd_switch_list_item_t *pswitches; /* WR: pointer to list item array */
 	char reserved[12];
 } snd_switch_list_t;
 
 typedef struct snd_switch {
-	int iface;		/* interface number */
-	int device;		/* device number */
-	int channel;		/* channel number */
-	unsigned char name[32];	/* unique identification of switch (from driver) */
-	unsigned int type;	/* look to SND_SW_TYPE_* */
-	unsigned int subtype;	/* look to SND_SW_SUBTYPE_* */
-	unsigned int low;	/* low range value */
-	unsigned int high;	/* high range value */
+	int iface;		/* WR: interface number */
+	int device;		/* WR: device number */
+	int channel;		/* WR: channel number */
+	unsigned char name[32];	/* WR: unique identification of switch (from driver) */
+	unsigned int type;	/* RW: look to SND_SW_TYPE_* */
+	unsigned int subtype;	/* RW: look to SND_SW_SUBTYPE_* */
+	unsigned int low;	/* RO: low range value */
+	unsigned int high;	/* RO: high range value */
 	union {
 		unsigned int enable: 1;		/* 0 = off, 1 = on */
 		unsigned char data8[32];	/* 8-bit data */
 		unsigned short data16[16];	/* 16-bit data */
 		unsigned int data32[8];		/* 32-bit data */
-		int item_number;		/* active list item number */
+		unsigned int item_number;	/* active list item number */
 		char item[32];			/* list item, low -> item number */
-	} value;
+	} value;		/* RO */
 	unsigned char reserved[32];
 } snd_switch_t;
  
@@ -313,9 +314,9 @@ typedef struct snd_hwdep_info {
 #define SND_MIXER_ETYPE_ADC		6
 /* DAC */
 #define SND_MIXER_ETYPE_DAC		7
-/* simple on/off switch */
+/* simple on/off switch (voices separated) */
 #define SND_MIXER_ETYPE_SWITCH1		100
-/* simple on/off switch for each voices */
+/* simple on/off switch (all voices together) */
 #define SND_MIXER_ETYPE_SWITCH2		101
 /* simple voice route switch */
 #define SND_MIXER_ETYPE_SWITCH3		102
@@ -329,9 +330,9 @@ typedef struct snd_hwdep_info {
 #define SND_MIXER_ETYPE_ACCU2		301
 /* simple accumulator with programmable attenuation */
 #define SND_MIXER_ETYPE_ACCU3		302
-/* simple MUX */
+/* simple MUX (voices separated) */
 #define SND_MIXER_ETYPE_MUX1		400
-/* simple MUX with one control for each voices */
+/* simple MUX (all voices together) */
 #define SND_MIXER_ETYPE_MUX2		401
 /* simple tone control */
 #define SND_MIXER_ETYPE_TONE_CONTROL1	500
@@ -380,8 +381,8 @@ typedef struct {
 
 typedef struct snd_mixer_info {
 	unsigned int type;	/* type of soundcard - SND_CARD_TYPE_XXXX */
-	unsigned int attrib;	/* some attributes about this device (SND_MIXER_ATTR_*) */
-	unsigned char id[64];	/* ID of this mixer (user selectable) */
+	unsigned int attrib;	/* attributes, not used */
+	unsigned char id[64];	/* ID of this mixer */
 	unsigned char name[80];	/* name of this device */
 	int elements;		/* count of elements */
 	int groups;		/* count of element groups */
@@ -393,10 +394,10 @@ typedef struct snd_mixer_info {
  */
 
 typedef struct snd_mixer_elements {
-	int elements_size;	/* size in element identifiers */
-	int elements;		/* count of filled element identifiers */
-	int elements_over;	/* missing element identifiers */
-	snd_mixer_eid_t *pelements; /* array */
+	int elements_size;	/* WR: size in element identifiers */
+	int elements;		/* WR: count of filled element identifiers */
+	int elements_over;	/* RO: missing element identifiers */
+	snd_mixer_eid_t *pelements; /* WR: array */
 } snd_mixer_elements_t;
 
 /*
@@ -404,11 +405,11 @@ typedef struct snd_mixer_elements {
  */
 
 typedef struct snd_mixer_routes {
-	snd_mixer_eid_t eid;
-	int routes_size;	/* size in element identifiers */
-	int routes;		/* count of filled element identifiers */
-	int routes_over;	/* missing element identifiers */
-	snd_mixer_eid_t *proutes; /* array */
+	snd_mixer_eid_t eid;	/* WR: element identifier */
+	int routes_size;	/* WR: size in element identifiers */
+	int routes;		/* RO: count of filled element identifiers */
+	int routes_over;	/* RO: missing element identifiers */
+	snd_mixer_eid_t *proutes; /* WR: array */
 } snd_mixer_routes_t;
 
 /*
@@ -416,10 +417,10 @@ typedef struct snd_mixer_routes {
  */
 
 typedef struct snd_mixer_groups {
-	int groups_size;	/* size in group identifiers */
-	int groups;		/* count of filled group identifiers */
-	int groups_over;	/* missing group identifiers */
-	snd_mixer_gid_t *pgroups; /* array */
+	int groups_size;	/* WR: size in group identifiers */
+	int groups;		/* RO: count of filled group identifiers */
+	int groups_over;	/* RO: missing group identifiers */
+	snd_mixer_gid_t *pgroups; /* WR: array */
 } snd_mixer_groups_t;
 
 typedef enum {
@@ -451,18 +452,18 @@ typedef enum {
 #define SND_MIXER_GRPCAP_EXCL_CAPTURE	(1<<6)
 
 typedef struct snd_mixer_group {
-	snd_mixer_gid_t gid;
-	int elements_size;		/* size in element identifiers */
-	int elements;			/* count of filled element identifiers */
-	int elements_over;		/* missing element identifiers */
-	snd_mixer_eid_t *pelements;	/* array */
-	unsigned int caps;		/* capabilities */
-	unsigned int channels;		/* bitmap of active channels */	
-	unsigned int mute;		/* bitmap of muted channels */
-	unsigned int capture;		/* bitmap of capture channels */
-	int capture_group;		/* capture group (for exclusive capture source) */
-	int min;			/* minimum value */
-	int max;			/* maximum value */
+	snd_mixer_gid_t gid;		/* WR: group identification */
+	int elements_size;		/* WR: size in element identifiers */
+	int elements;			/* RO: count of filled element identifiers */
+	int elements_over;		/* RO: missing element identifiers */
+	snd_mixer_eid_t *pelements;	/* WR: array */
+	unsigned int caps;		/* RO: capabilities */
+	unsigned int channels;		/* RO: bitmap of active channels */	
+	unsigned int mute;		/* RW: bitmap of muted channels */
+	unsigned int capture;		/* RW: bitmap of capture channels */
+	int capture_group;		/* RO: capture group (for exclusive capture source) */
+	int min;			/* RO: minimum value */
+	int max;			/* RO: maximum value */
 	union {
 		struct {
 			int front_left;		/* front left value */
@@ -472,7 +473,7 @@ typedef struct snd_mixer_group {
 			int rear_right;		/* right rear */
 			int woofer;		/* woofer */
 		} names;
-		int values[32];
+		int values[32];		/* RW */
 	} volume;
 } snd_mixer_group_t;
 
@@ -485,11 +486,11 @@ typedef struct snd_mixer_group {
 #define SND_MIXER_EIO_DIGITAL		(0<<1)
 
 struct snd_mixer_element_io_info {
-	unsigned int attrib;		/* SND_MIXER_EIO_* */
-	int voices_size;		/* size in voice descriptors */
-	int voices;			/* count of filled voice descriptors */
-	int voices_over;		/* missing voice descriptors */
-	snd_mixer_voice_t *pvoices;	/* array */
+	unsigned int attrib;		/* RO: SND_MIXER_EIO_* */
+	int voices_size;		/* WR: size in voice descriptors */
+	int voices;			/* RO: count of filled voice descriptors */
+	int voices_over;		/* RO: missing voice descriptors */
+	snd_mixer_voice_t *pvoices;	/* WR: array */
 };
 
 /*
@@ -499,15 +500,15 @@ struct snd_mixer_element_io_info {
  */
 
 struct snd_mixer_element_pcm1_info {
-	int devices_size;		/* size in device descriptors */
-	int devices;			/* count of filled device descriptors */
-	int devices_over;		/* missing device descriptors */
-	int *pdevices;			/* PCM devices - array */
+	int devices_size;		/* WR: size in device descriptors */
+	int devices;			/* RO: count of filled device descriptors */
+	int devices_over;		/* RO: missing device descriptors */
+	int *pdevices;			/* WR: PCM devices - array */
 };
 
 struct snd_mixer_element_pcm2_info {
-	int device;
-	int subdevice;
+	int device;			/* RO: device index */
+	int subdevice;			/* RO: subdevice index */
 };
 
 /*
@@ -517,7 +518,7 @@ struct snd_mixer_element_pcm2_info {
  */
 
 struct snd_mixer_element_converter_info {
-	unsigned int resolution;	/* resolution in bits (usually 16) */
+	unsigned int resolution;	/* RO: resolution in bits (usually 16) */
 };
 
 /*
@@ -527,10 +528,10 @@ struct snd_mixer_element_converter_info {
  */
 
 struct snd_mixer_element_switch1 {
-	int sw_size;			/* size of bitmap (in bits) */
-	int sw;				/* count of filled bits */
-	int sw_over;			/* missing bits */
-	unsigned int *psw;		/* bitmap!!! */
+	int sw_size;			/* WR: size of bitmap (in bits) */
+	int sw;				/* RO: count of filled bits */
+	int sw_over;			/* RO: missing bits */
+	unsigned int *psw;		/* WR: bitmap!!! */
 };
 
 /*
@@ -540,7 +541,7 @@ struct snd_mixer_element_switch1 {
  */
 
 struct snd_mixer_element_switch2 {
-	unsigned int sw:1;
+	unsigned int sw:1;		/* WR */
 };
 
 /*
@@ -555,7 +556,7 @@ struct snd_mixer_element_switch2 {
 #define SND_MIXER_SWITCH3_ALWAYS_ONE_DESTINATION	3
 
 struct snd_mixer_element_switch3_info {
-	unsigned int type;		/* SND_MIXER_SWITCH3_* */
+	unsigned int type;		/* RO: SND_MIXER_SWITCH3_* */
 	/* X = output / Y = input voice descriptors */
 	int voices_size;		/* size in voice descriptors */
 	int voices;			/* count of filled voice descriptors */
@@ -565,10 +566,10 @@ struct snd_mixer_element_switch3_info {
 
 struct snd_mixer_element_switch3 {
 	/* two dimensional matrix of voice route switch */
-	int rsw_size;			/* size in voice route descriptors (must be voice_size * voice_size bits !!!) */
-	int rsw;			/* count of filled voice route descriptors */
-	int rsw_over;			/* missing voice descriptors */
-	unsigned int *prsw;		/* array */
+	int rsw_size;			/* WR: size in voice route descriptors (must be voice_size * voice_size bits !!!) */
+	int rsw;			/* RO: count of filled voice route descriptors */
+	int rsw_over;			/* RO: missing voice descriptors */
+	unsigned int *prsw;		/* WR: array */
 };
 
 /*
@@ -578,22 +579,22 @@ struct snd_mixer_element_switch3 {
  */
 
 struct snd_mixer_element_volume1_range {
-	int min, max;		/* linear volume */
-	int min_dB, max_dB;	/* negative - attenuation, positive - amplification */
+	int min, max;		/* RO: linear volume */
+	int min_dB, max_dB;	/* RO: negative - attenuation, positive - amplification */
 };
 
 struct snd_mixer_element_volume1_info {
-	int range_size;		/* size of range descriptors */
-	int range;		/* count of filled range descriptors */
-	int range_over;		/* missing range descriptors */
-	struct snd_mixer_element_volume1_range *prange;	/* array */
+	int range_size;		/* WR: size of range descriptors */
+	int range;		/* RO: count of filled range descriptors */
+	int range_over;		/* RO: missing range descriptors */
+	struct snd_mixer_element_volume1_range *prange;	/* WR: array */
 };
 
 struct snd_mixer_element_volume1 {
-	int voices_size;	/* size of voice descriptors */	
-	int voices;		/* count of filled voice descriptors */
-	int voices_over;	/* missing voice descriptors */
-	int *pvoices;		/* array of volumes */
+	int voices_size;	/* WR: size of voice descriptors */	
+	int voices;		/* RO: count of filled voice descriptors */
+	int voices_over;	/* RO: missing voice descriptors */
+	int *pvoices;		/* WR: array of volumes */
 };
 
 /*
@@ -610,25 +611,25 @@ struct snd_mixer_element_volume2_range {
 
 struct snd_mixer_element_volume2_info {
 	/* source voices */
-	int svoices_size;
-	int svoices;
-	int svoices_over;
-	snd_mixer_voice_t *psvoices;
+	int svoices_size;	/* WR: size of source voices */
+	int svoices;		/* RO: count of filled voice descriptors */
+	int svoices_over;	/* RO: missing voice descriptors */
+	snd_mixer_voice_t *psvoices; /* WR: array of voices */
 	/* destonation ranges */
-	int range_size;		/* size of range descriptors */
-	int range;		/* count of filled range descriptors */
-	int range_over;		/* missing range descriptors */
-	struct snd_mixer_element_volume2_range *prange;	/* array */
+	int range_size;		/* WR: size of range descriptors */
+	int range;		/* RO: count of filled range descriptors */
+	int range_over;		/* RO: missing range descriptors */
+	struct snd_mixer_element_volume2_range *prange;	/* WR: array */
 };
 
 /* avoices means the array of voices which describes volume offsets for */
 /* each outputs, the size of this array is info->svoices * info->range */
 
 struct snd_mixer_element_volume2 {
-	int avoices_size;	/* size of voice descriptors */	
-	int avoices;		/* count of filled voice descriptors */
-	int avoices_over;	/* missing voice descriptors */
-	int *pavoices;		/* array of volumes */
+	int avoices_size;	/* WR: size of voice descriptors */	
+	int avoices;		/* RO: count of filled voice descriptors */
+	int avoices_over;	/* RO: missing voice descriptors */
+	int *pavoices;		/* WR: array of volumes */
 };
 
 /*
@@ -636,7 +637,7 @@ struct snd_mixer_element_volume2 {
  */
 
 struct snd_mixer_element_accu1_info {
-	int attenuation;		/* in dB */
+	int attenuation;		/* RO: in dB */
 };
 
 /*
@@ -644,7 +645,7 @@ struct snd_mixer_element_accu1_info {
  */
 
 struct snd_mixer_element_accu2_info {
-	int attenuation;		/* in dB */
+	int attenuation;		/* RO: in dB */
 };
 
 /* 
@@ -652,58 +653,58 @@ struct snd_mixer_element_accu2_info {
  */
 
 struct snd_mixer_element_accu3_range {
-	int min, max;		/* linear volume */
-	int min_dB, max_dB;	/* negative - attenuation, positive - amplification */
+	int min, max;		/* RO: linear volume */
+	int min_dB, max_dB;	/* RO: negative - attenuation, positive - amplification */
 };
 
 struct snd_mixer_element_accu3_info {
-	int range_size;		/* size of range descriptors */
-	int range;		/* count of filled range descriptors */
-	int range_over;		/* missing range descriptors */
-	struct snd_mixer_element_accu3_range *prange;	/* array */
+	int range_size;		/* WR: size of range descriptors */
+	int range;		/* RO: count of filled range descriptors */
+	int range_over;		/* RO: missing range descriptors */
+	struct snd_mixer_element_accu3_range *prange;	/* WR: array */
 };
 
 struct snd_mixer_element_accu3 {
-	int voices_size;	/* size of voice descriptors */	
-	int voices;		/* count of filled voice descriptors */
-	int voices_over;	/* missing voice descriptors */
-	int *pvoices;		/* array of volumes */
+	int voices_size;	/* WR: size of voice descriptors */	
+	int voices;		/* RO: count of filled voice descriptors */
+	int voices_over;	/* RO: missing voice descriptors */
+	int *pvoices;		/* WR: array of volumes */
 };
 
 /*
  *  Simple MUX
  *
- *     This mux allows selection of some (or none - optional) input.
- *     Each voices have got the separate control.
+ *     This mux allows selection of exactly one (or none - optional) source
+ *     per each voice.
  */
 
 #define SND_MIXER_MUX1_NONE		(1<<0)
 
 struct snd_mixer_element_mux1_info {
-	unsigned int attrib;		/* SND_MIXER_MUX1_ */
+	unsigned int attrib;		/* RO: SND_MIXER_MUX1_ */
 };
 
 struct snd_mixer_element_mux1 {
-	int output_size;
-	int output;
-	int output_over;
-	snd_mixer_eid_t *poutput;	/* input source on output */
+	int output_size;		/* WR: size of mixer elements */
+	int output;			/* RO: count of mixer elements */
+	int output_over;		/* RO: missing voice elements */
+	snd_mixer_eid_t *poutput;	/* WR: selected source on element output */
 };
 
 /*
  *  Simple MUX
  *
- *     This mux allows selection of exactly one (or none - optional) input.
+ *     This mux allows selection of exactly one (or none - optional) source.
  */
 
 #define SND_MIXER_MUX2_NONE		(1<<0)
 
 struct snd_mixer_element_mux2_info {
-	unsigned int attrib;		/* SND_MIXER_MUX1_ */
+	unsigned int attrib;		/* RO: SND_MIXER_MUX1_ */
 };
 
 struct snd_mixer_element_mux2 {
-	snd_mixer_eid_t output;		/* input source on output */
+	snd_mixer_eid_t output;		/* RO: input source on element output */
 };
 
 /*
@@ -715,18 +716,18 @@ struct snd_mixer_element_mux2 {
 #define SND_MIXER_TC1_TREBLE		(1<<2)
 
 struct snd_mixer_element_tone_control1_info {
-	unsigned int tc;		/* bitmap of SND_MIXER_TC_* */
-	int min_bass, max_bass;		/* Bass */
-	int min_bass_dB, max_bass_dB;	/* in decibels * 100 */
-	int min_treble, max_treble;	/* Treble */
-	int min_treble_dB, max_treble_dB; /* in decibels * 100 */
+	unsigned int tc;		/* RO: bitmap of SND_MIXER_TC_* */
+	int min_bass, max_bass;		/* RO: Bass */
+	int min_bass_dB, max_bass_dB;	/* RO: in decibels * 100 */
+	int min_treble, max_treble;	/* RO: Treble */
+	int min_treble_dB, max_treble_dB; /* RO: in decibels * 100 */
 };
 
 struct snd_mixer_element_tone_control1 {
-	unsigned int tc;		/* bitmap of SND_MIXER_TC_* */
-	unsigned int sw:1;		/* on/off switch */
-	int bass;			/* Bass control */
-	int treble;			/* Treble control */
+	unsigned int tc;		/* WR: bitmap of SND_MIXER_TC_* */
+	unsigned int sw:1;		/* WR: on/off switch */
+	int bass;			/* WR: Bass control */
+	int treble;			/* WR: Treble control */
 };
 
 /*
@@ -738,23 +739,23 @@ struct snd_mixer_element_tone_control1 {
 #define SND_MIXER_PAN_BOTTOM_UP         2
 
 struct snd_mixer_element_pan_control1_range {
-	int pan_type;			/* SND_MIXER_PAN_XXXX */
-	int min, max;
-	int min_dB, max_dB;
+	int pan_type;			/* RO: SND_MIXER_PAN_XXXX */
+	int min, max;			/* RO: min & max range */
+	int min_dB, max_dB;		/* RO: min dB & max dB range */
 };
 
 struct snd_mixer_element_pan_control1_info {
-	int range_size;		/* size of range descriptors */
-	int range;		/* count of filled range descriptors */
-	int range_over;		/* missing range descriptors */
-	struct snd_mixer_element_pan_control1_range *prange;
+	int range_size;		/* WR: size of range descriptors */
+	int range;		/* RO: count of filled range descriptors */
+	int range_over;		/* RO: missing range descriptors */
+	struct snd_mixer_element_pan_control1_range *prange; /* WR: array */
 };
 
 struct snd_mixer_element_pan_control1 {
-	int pan_size;		/* size of pan descriptors */
-	int pan;		/* count of filled pan descriptors */
-	int pan_over;		/* missing pan descriptors */
-	int *ppan;		/* array of pan values */
+	int pan_size;		/* WR: size of pan descriptors */
+	int pan;		/* RO: count of filled pan descriptors */
+	int pan_over;		/* RO: missing pan descriptors */
+	int *ppan;		/* WR: array of pan values */
 };
 
 /*
@@ -780,29 +781,29 @@ struct snd_mixer_element_pan_control1 {
 #define SND_MIXER_EFF1_DEPTH_REAR	(1<<9)
 
 struct snd_mixer_element_3d_effect1_info {
-	unsigned int effect;		/* bitmap of SND_MIXER_EFF1_* */
-	int min_wide, max_wide;		/* 3D wide */
-	int min_volume, max_volume;	/* 3D volume */
-	int min_center, max_center;	/* 3D center */
-	int min_space, max_space;	/* 3D space */
-	int min_depth, max_depth;	/* 3D depth */
-	int min_delay, max_delay;	/* 3D delay */
-	int min_feedback, max_feedback;	/* 3D feedback */
-	int min_depth_rear, max_depth_rear;	/* 3D depth rear */
+	unsigned int effect;		/* RO: bitmap of SND_MIXER_EFF1_* */
+	int min_wide, max_wide;		/* RO: 3D wide */
+	int min_volume, max_volume;	/* RO: 3D volume */
+	int min_center, max_center;	/* RO: 3D center */
+	int min_space, max_space;	/* RO: 3D space */
+	int min_depth, max_depth;	/* RO: 3D depth */
+	int min_delay, max_delay;	/* RO: 3D delay */
+	int min_feedback, max_feedback;	/* RO: 3D feedback */
+	int min_depth_rear, max_depth_rear;	/* RO: 3D depth rear */
 };
 
 struct snd_mixer_element_3d_effect1 {
-	unsigned int effect;		/* bitmap of SND_MIXER_EFF1_* */
-	unsigned int sw:1,		/* on/off switch */
-		     mono_sw:1;		/* on/off switch */
-	int wide;			/* 3D wide */
-	int volume;			/* 3D volume */
-	int center;			/* 3D center */
-	int space;			/* 3D space */
-	int depth;			/* 3D depth */
-	int delay;			/* 3D delay */
-	int feedback;			/* 3D feedback */
-	int depth_rear;			/* 3D depth rear */
+	unsigned int effect;		/* RW: bitmap of SND_MIXER_EFF1_* */
+	unsigned int sw:1,		/* RW: on/off switch */
+		     mono_sw:1;		/* RW: on/off switch */
+	int wide;			/* RW: 3D wide */
+	int volume;			/* RW: 3D volume */
+	int center;			/* RW: 3D center */
+	int space;			/* RW: 3D space */
+	int depth;			/* RW: 3D depth */
+	int delay;			/* RW: 3D delay */
+	int feedback;			/* RW: 3D feedback */
+	int depth_rear;			/* RW: 3D depth rear */
 };
 
 /*
@@ -814,29 +815,29 @@ struct snd_mixer_element_pre_effect1_info_item {
 };
 
 struct snd_mixer_element_pre_effect1_info_parameter {
-	char name[32];
-	int min, max;			/* minimum and maximum value */
+	char name[32];			/* RO: parameter name */
+	int min, max;			/* RO: minimum and maximum value */
 };
 
 struct snd_mixer_element_pre_effect1_info {
 	/* predefined programs */
-	int items_size;
-	int items;
-	int items_over;
-	struct snd_mixer_element_pre_effect1_info_item *pitems;
+	int items_size;			/* WR: size of programs */
+	int items;			/* RO: count of filled programs */
+	int items_over;			/* RO: missing programs */
+	struct snd_mixer_element_pre_effect1_info_item *pitems; /* WR: array */
 	/* user parameters */
-	int parameters_size;
-	int parameters;
-	int parameters_over;
-	struct snd_mixer_element_pre_effect1_info_parameter *pparameters;
+	int parameters_size;		/* WR: size of parameters */
+	int parameters;			/* RO: count of filled parameters */
+	int parameters_over;		/* RO: missing parameters */
+	struct snd_mixer_element_pre_effect1_info_parameter *pparameters; /* WR: array */
 };
 
 struct snd_mixer_element_pre_effect1 {
-	int item;			/* chose item index or -1 = user parameters */
-	int parameters_size;
-	int parameters;
-	int parameters_over;
-	int *pparameters;
+	int item;			/* WR: chose item index or -1 = user parameters */
+	int parameters_size;		/* WR: size of parameters */
+	int parameters;			/* RO: count of filled parameters */
+	int parameters_over;		/* RO: missing parameters */
+	int *pparameters;		/* WR: array */
 };
 
 /*
@@ -844,7 +845,7 @@ struct snd_mixer_element_pre_effect1 {
  */
 
 typedef struct snd_mixer_element_info {
-	snd_mixer_eid_t eid;
+	snd_mixer_eid_t eid;		/* WR: element identification */
 	union {
 		struct snd_mixer_element_io_info io;
 		struct snd_mixer_element_pcm1_info pcm1;
