@@ -94,7 +94,7 @@
 #define SND_CARD_TYPE_AWACS		0x0000003c	/* PMac AWACS */
 #define SND_CARD_TYPE_ALI_5451		0x0000003d	/* ALi 5451 */
 #define SND_CARD_TYPE_CS4281		0x0000003e	/* CS4281 */
-#define SND_CARD_TYPE_ALLEGRO_1		0x0000003f	/* ESS Allegro-1 */
+#define SND_CARD_TYPE_CANYON3D_2	0x0000003f	/* ESS Canyon-2 */
 #define SND_CARD_TYPE_ALLEGRO		0x00000040	/* ESS Allegro */
 #define SND_CARD_TYPE_MAESTRO3		0x00000041	/* ESS Maestro3 */
 #define SND_CARD_TYPE_NM256AV		0x00000042	/* NM256AV */
