@@ -1679,6 +1679,12 @@ struct snd_stru_cs461x {
 	snd_kmixer_t *mixer;
 	snd_rawmidi_t *rmidi;
 
+	int amplifier;
+	void (*amplifier_ctrl)(cs461x_t *, int);
+	void (*active_ctrl)(cs461x_t *, int);
+	struct pci_dev *acpi_dev;
+	int acpi_port;
+
 	void *entry_proc_BA0;
 	void *entry_proc_BA1_data0;
 	void *entry_proc_BA1_data1;
@@ -1689,7 +1695,7 @@ struct snd_stru_cs461x {
 	unsigned int midcr;
 	unsigned int uartm;
 	snd_info_entry_t *proc_entry;
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
 	struct pm_dev *pm_dev;
 #endif
 };
@@ -1699,6 +1705,7 @@ int snd_cs461x_create(snd_card_t * card,
 		      snd_dma_t * dma1ptr,
 		      snd_dma_t * dma2ptr,
 		      snd_irq_t * irqptr,
+		      int external_amp, int thinkpad,
 		      cs461x_t ** rcodec);
 int snd_cs461x_free(cs461x_t * codec);
 void snd_cs461x_interrupt(cs461x_t * codec);
