@@ -618,9 +618,16 @@ struct snd_stru_emu10k1_pcm {
 	unsigned int capture_bufsize;	/* buffer size in bytes */
 };
 
-typedef struct snd_emu10k1_memblk_arg {
-	short first_page, last_page;
-} snd_emu10k1_memblk_arg_t;
+typedef struct snd_emu10k1_memblk {
+	snd_emux_memblk_t mem;
+	/* private part */
+	short first_page, last_page, pages, mapped_page;
+	unsigned int map_locked;
+	struct list_head mapped_link;
+	struct list_head mapped_order_link;
+} emu10k1_memblk_t;
+
+#define snd_emu10k1_memblk_offset(blk)	(((blk)->mapped_page << PAGE_SHIFT) | ((blk)->mem.offset & (PAGE_SIZE - 1)))
 
 struct snd_stru_emu10k1 {
 	snd_dma_t * dma1ptr;	/* DAC1 */
@@ -634,11 +641,18 @@ struct snd_stru_emu10k1 {
 	unsigned int serial;	/* serial number */
 	unsigned short model;	/* subsystem id */
 	unsigned int ecard_ctrl; /* ecard control bits */
+	int max_cache_pages;			/* max memory size / PAGE_SIZE */
 
 	void *silent_page;	/* silent page */
 	volatile unsigned int *ptb_pages; /* page table pages */
 	snd_emux_memhdr_t *memhdr;	/* page allocation list */
-	snd_emux_memblk_t *reserved_page;	/* reserved page */
+	emu10k1_memblk_t *reserved_page;	/* reserved page */
+
+	struct list_head mapped_link_head;
+	struct list_head mapped_order_link_head;
+	void **page_ptr_table;
+	unsigned long *page_addr_table;
+	spinlock_t memblk_lock;
 
 	ac97_t *ac97;
 
@@ -693,6 +707,7 @@ int snd_emu10k1_create(snd_card_t * card,
 		       snd_dma_t * dma1ptr,
 		       snd_dma_t * dma2ptr,
 		       snd_irq_t * irqptr,
+		       long max_cache_bytes,
 		       emu10k1_t ** remu);
 
 int snd_emu10k1_pcm(emu10k1_t * emu, int device, snd_pcm_t ** rpcm);
@@ -727,6 +742,7 @@ snd_emux_memblk_t *snd_emu10k1_synth_alloc(emu10k1_t *emu, unsigned int size);
 int snd_emu10k1_synth_free(emu10k1_t *emu, snd_emux_memblk_t *blk);
 int snd_emu10k1_synth_bzero(emu10k1_t *emu, snd_emux_memblk_t *blk, int offset, int size);
 int snd_emu10k1_synth_copy_from_user(emu10k1_t *emu, snd_emux_memblk_t *blk, int offset, const char *data, int size);
+int snd_emu10k1_memblk_map(emu10k1_t *emu, emu10k1_memblk_t *blk);
 
 /* voice allocation */
 int snd_emu10k1_voice_alloc(emu10k1_t *emu, emu10k1_voice_type_t type, int pair, emu10k1_voice_t **rvoice);
