@@ -27,6 +27,7 @@
 #endif
 
 typedef struct snd_stru_pcm_file snd_pcm_file_t;
+typedef struct snd_stru_pcm_runtime snd_pcm_runtime_t;
 typedef struct snd_stru_pcm_subchn snd_pcm_subchn_t;
 typedef struct snd_stru_pcm_channel snd_pcm_channel_t;
 
@@ -104,7 +105,7 @@ struct snd_stru_pcm_file {
 	void (*private_free)(void *private_data);
 };
 
-typedef struct snd_stru_pcm_runtime {
+struct snd_stru_pcm_runtime {
 	int mode;			/* channel mode */
 	volatile int *status;		/* channel status */
 	int _sstatus;			/* static status location */
@@ -162,7 +163,7 @@ typedef struct snd_stru_pcm_runtime {
 	snd_pcm_hardware_t *hw;
 	void (*hw_free)(void *hw);
 	int (*hw_memcpy)(snd_pcm_subchn_t *subchn, int voice, int pos,
-			 const void *src, int count);
+			 void *src, int count);
 	int (*hw_memset)(snd_pcm_subchn_t *subchn, int voice, int pos,
 			 int c, int count);
 	/* -- interrupt callbacks -- */
@@ -178,7 +179,7 @@ typedef struct snd_stru_pcm_runtime {
 	/* -- OSS things -- */
 	snd_pcm_oss_runtime_t oss;
 #endif
-} snd_pcm_runtime_t;
+};
 
 struct snd_stru_pcm_subchn {
 	snd_pcm_t *pcm;
@@ -307,7 +308,9 @@ extern int snd_pcm_format_unsigned(int format);
 extern int snd_pcm_format_linear(int format);
 extern int snd_pcm_format_little_endian(int format);
 extern int snd_pcm_format_big_endian(int format);
-extern int snd_pcm_format_width(int format);		/* in bits */
+extern int snd_pcm_format_width(int format);			/* in bits */
+extern int snd_pcm_format_physical_width(int format);		/* in bits */
+extern unsigned char snd_pcm_format_silence(int format);
 extern int snd_pcm_build_linear_format(int width, int unsignd, int big_endian);
 extern ssize_t snd_pcm_format_size(int format, size_t samples);
  
@@ -318,7 +321,6 @@ extern void snd_pcm_set_sync(snd_pcm_subchn_t * subchn);
 extern void snd_pcm_set_mixer(snd_pcm_subchn_t * subchn, int mixer_device, snd_kmixer_element_t * element);
 extern unsigned int snd_pcm_lib_transfer_size(snd_pcm_subchn_t *subchn);
 extern unsigned int snd_pcm_lib_transfer_fragment(snd_pcm_subchn_t *subchn);
-extern unsigned char snd_pcm_lib_silence(snd_pcm_subchn_t *subchn);
 extern int snd_pcm_lib_interleave_len(snd_pcm_subchn_t *subchn);
 extern int snd_pcm_lib_set_buffer_size(snd_pcm_subchn_t *subchn, long size);
 extern int snd_pcm_lib_mmap_ctrl_ptr(snd_pcm_subchn_t *subchn, char *ptr);
