@@ -391,6 +391,7 @@ int snd_register_dma_channel(snd_card_t * card, char *name, unsigned long number
 		}
 	}
 	snd_debug_check(rsize < 4 || rsize > 1024, -EINVAL);
+#ifdef CONFIG_SND_ISA
 	if (type == SND_DMA_TYPE_ISA) {
 		snd_debug_check(rsize > 128, -EINVAL);
 	}
@@ -422,9 +423,12 @@ int snd_register_dma_channel(snd_card_t * card, char *name, unsigned long number
 			rsize = 64;
 		snd_debug_check(number > 7, -EINVAL);
 	} else {
+#endif /* CONFIG_SND_ISA */
 		snd_debug_check(possible_numbers, -EINVAL);
 		snd_debug_check(number > 255, -EINVAL);
+#ifdef CONFIG_SND_ISA
 	}
+#endif /* CONFIG_SND_ISA */
 	dmaptr = (snd_dma_t *) snd_kcalloc(sizeof(snd_dma_t), GFP_KERNEL);
 	if (dmaptr == NULL)
 		return -ENOMEM;
@@ -434,6 +438,7 @@ int snd_register_dma_channel(snd_card_t * card, char *name, unsigned long number
 	dmaptr->rsize = rsize * 1024;
 	dmaptr->name = snd_kmalloc_strdup(name, GFP_KERNEL);
 	init_MUTEX(&dmaptr->mutex);
+#ifdef CONFIG_SND_ISA
 	if (type == SND_DMA_TYPE_ISA) {
 		if (request_dma(number, dmaptr->name)) {
 			snd_printk("unable to grab DMA %li for %s\n",
@@ -443,6 +448,7 @@ int snd_register_dma_channel(snd_card_t * card, char *name, unsigned long number
 			return -EBUSY;
 		}
 	}
+#endif /* CONFIG_SND_ISA */
 	if (card->dmas == NULL) {
 		card->dmas = dmaptr;
 	} else {
@@ -462,10 +468,12 @@ int snd_unregister_dma_channels(snd_card_t * card)
 	card->dmas = NULL;
 	while (dmaptr) {
 		dmaptrnext = dmaptr->next;
+#ifdef CONFIG_SND_ISA
 		if (dmaptr->type == SND_DMA_TYPE_ISA) {
 			snd_dma_disable(dmaptr->dma);
 			free_dma(dmaptr->dma);
 		}
+#endif /* CONFIG_SND_ISA */
 		snd_kfree(dmaptr->name);
 		snd_kfree(dmaptr);
 		dmaptr = dmaptrnext;
