@@ -43,6 +43,7 @@ static LIST_HEAD(pci_drivers);
 struct pci_driver_mapping {
 	struct pci_dev *dev;
 	struct pci_driver *drv;
+	unsigned long dma_mask;
 	void *driver_data;
 };
 
@@ -74,6 +75,30 @@ void snd_pci_compat_set_driver_data (struct pci_dev *dev, void *driver_data)
 }
 
 
+unsigned long snd_pci_compat_get_dma_mask (struct pci_dev *dev)
+{
+	int i;
+	
+	for (i = 0; i < PCI_MAX_MAPPINGS; i++)
+		if (drvmap[i].dev == dev)
+			return drvmap[i].dma_mask;
+	
+	return 0;
+}
+
+
+void snd_pci_compat_set_dma_mask (struct pci_dev *dev, unsigned long mask)
+{
+	int i;
+	
+	for (i = 0; i < PCI_MAX_MAPPINGS; i++)
+		if (drvmap[i].dev == dev) {
+			drvmap[i].dma_mask = mask;
+			return;
+		} 
+}
+
+
 const struct pci_device_id * snd_pci_compat_match_device(const struct pci_device_id *ids, struct pci_dev *dev)
 {
 	u16 subsystem_vendor, subsystem_device;
@@ -109,6 +134,7 @@ static int snd_pci_announce_device(struct pci_driver *drv, struct pci_dev *dev)
 	        if (drvmap[i].dev == NULL) {
 	                drvmap[i].dev = dev;
 	                drvmap[i].drv = drv;
+			drvmap[i].dma_mask = ~0UL;
 	                break;
 	        }
         }
@@ -272,7 +298,12 @@ int snd_pci_compat_find_capability(struct pci_dev *dev, int cap)
 	return 0;
 }
 
-#endif /* kernel version < 2.3.0 && CONFIG_PCM */
+int snd_pci_compat_dma_supported(struct pci_dev *dev, dma_addr_t mask)
+{
+	return 1;
+}
+
+#endif /* kernel version < 2.3.0 && CONFIG_PCI */
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0) && defined(CONFIG_APM)
 
