@@ -896,7 +896,7 @@ static int snd_pcm_mmap(struct inode *inode, struct file *file,
 			return -ENOMEM;
 		vma->notify = snd_pcm_vma_notify_control;
 		vma->notify_client = subchn;
-		runtime->mmap_control = (snd_pcm_mmap_control_t *) snd_malloc_pages(sizeof(snd_pcm_mmap_control_t), NULL, 0);
+		runtime->mmap_control = (snd_pcm_mmap_control_t *) snd_malloc_pages(sizeof(snd_pcm_mmap_control_t), NULL, GFP_KERNEL);
 		if (runtime->mmap_control == NULL) {
 			snd_kfree(vma);
 			return -ENOMEM;
