@@ -23,6 +23,7 @@
 #include "../../include/driver.h"
 #include "../../include/pcm.h"
 #include "../../include/pcm_plugin.h"
+#define bswap_16(x) __swab16((x))
 #else
 #include <stdio.h>
 #include <stdlib.h>
@@ -43,6 +44,7 @@ struct voices_private_data {
 	int dst_voices;
 	int width;		/* in bites */
 	int flg_signed: 1;
+	int swap: 1;
 };
 
 static void divide_8bit(char *src_ptr, char *dst_ptr, int size)
@@ -66,7 +68,9 @@ static void merge_8bit_unsigned(unsigned char *src_ptr,
 			        int size)
 {
 	while (size-- > 0) {
-		*dst_ptr++ = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		int tmp = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		if (tmp > 255) tmp = 255;
+		*dst_ptr++ = tmp;
 		src_ptr += 2;
 	}
 }
@@ -76,7 +80,10 @@ static void merge_8bit_signed(signed char *src_ptr,
 			      int size)
 {
 	while (size-- > 0) {
-		*dst_ptr++ = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		int tmp = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		if (tmp < -128) tmp = -128;
+		else if (tmp > 127) tmp = 127;
+		*dst_ptr++ = tmp;
 		src_ptr += 2;
 	}
 }
@@ -86,7 +93,9 @@ static void merge_16bit_unsigned(unsigned short *src_ptr,
 			         int size)
 {
 	while (size-- > 0) {
-		*dst_ptr++ = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		int tmp = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		if (tmp > 65535) tmp = 65535;
+		*dst_ptr++ = tmp;
 		src_ptr += 2;
 	}
 }
@@ -96,14 +105,42 @@ static void merge_16bit_signed(signed short *src_ptr,
 			       int size)
 {
 	while (size-- > 0) {
-		*dst_ptr++ = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		int tmp = ((int)*src_ptr + (int)*(src_ptr + 1)) / 2;
+		if (tmp < -32768) tmp = -32768;
+		else if (tmp > 32767) tmp = 32767;
+		*dst_ptr++ = tmp;
+		src_ptr += 2;
+	}
+}
+
+static void merge_16bit_unsigned_swap(unsigned short *src_ptr,
+				      unsigned short *dst_ptr,
+				      int size)
+{
+	while (size-- > 0) {
+		int tmp = ((int)bswap_16(*src_ptr) + (int)bswap_16(*(src_ptr + 1))) / 2;
+		if (tmp > 65535) tmp = 65535;
+		*dst_ptr++ = bswap_16((unsigned short)tmp);
+		src_ptr += 2;
+	}
+}
+
+static void merge_16bit_signed_swap(signed short *src_ptr,
+				    signed short *dst_ptr,
+				    int size)
+{
+	while (size-- > 0) {
+		int tmp = ((int)bswap_16(*src_ptr) + (int)bswap_16(*(src_ptr + 1))) / 2;
+		if (tmp < -32768) tmp = -32768;
+		else if (tmp > 32767) tmp = 32767;
+		*dst_ptr++ = bswap_16((short)tmp);
 		src_ptr += 2;
 	}
 }
 
 static ssize_t voices_transfer(snd_pcm_plugin_t *plugin,
 			     char *src_ptr, size_t src_size,
-			     char *dst_ptr, size_t dst_size UNUSED)
+			     char *dst_ptr, size_t dst_size ATTRIBUTE_UNUSED)
 {
 	struct voices_private_data *data;
 
@@ -129,9 +166,15 @@ static ssize_t voices_transfer(snd_pcm_plugin_t *plugin,
 	case 16:
 		if (data->src_voices > data->dst_voices) {
 			if (data->flg_signed) {
-				merge_16bit_signed((short *)src_ptr, (short *)dst_ptr, src_size / 4);
+				if (data->swap)
+					merge_16bit_signed_swap((short *)src_ptr, (short *)dst_ptr, src_size / 4);
+				else
+					merge_16bit_signed((short *)src_ptr, (short *)dst_ptr, src_size / 4);
 			} else {
-				merge_16bit_unsigned((short *)src_ptr, (short *)dst_ptr, src_size / 4);
+				if (data->swap)
+					merge_16bit_unsigned_swap((short *)src_ptr, (short *)dst_ptr, src_size / 4);
+				else
+					merge_16bit_unsigned((short *)src_ptr, (short *)dst_ptr, src_size / 4);
 			}
 		} else {
 			divide_16bit((short *)src_ptr, (short *)dst_ptr, src_size / 2);
@@ -204,6 +247,11 @@ int snd_pcm_plugin_build_voices(snd_pcm_format_t *src_format,
 	plugin->transfer = voices_transfer;
 	plugin->src_size = voices_src_size;
 	plugin->dst_size = voices_dst_size;
+#ifdef SND_LITTLE_ENDIAN
+	data->swap = src_format->format == SND_PCM_SFMT_S16_BE;
+#else
+	data->swap = src_format->format == SND_PCM_SFMT_S16_LE;
+#endif
 	*r_plugin = plugin;
 	return 0;
 }
