@@ -852,6 +852,7 @@ int snd_seq_dispatch_event(snd_seq_event_cell_t *cell, int atomic, int hop)
 
 		ev = &cell->event;
 		ev->type = SND_SEQ_EVENT_NOTEOFF;
+		ev->flags |= SND_SEQ_PRIORITY_HIGH;
 
 		/* add the duration time */
 		switch (ev->flags & SND_SEQ_TIME_STAMP_MASK) {
@@ -1727,7 +1728,7 @@ static int snd_seq_ioctl_get_queue_status(client_t * client, snd_seq_queue_statu
 {
 	snd_seq_queue_status_t status;
 	queue_t *queue;
-	timer_t *tmr;
+	seq_timer_t *tmr;
 
 	if (copy_from_user(&status, _status, sizeof(snd_seq_queue_status_t)))
 		return -EFAULT;
@@ -1759,7 +1760,7 @@ static int snd_seq_ioctl_get_queue_tempo(client_t * client, snd_seq_queue_tempo_
 {
 	snd_seq_queue_tempo_t tempo;
 	queue_t *queue;
-	timer_t *tmr;
+	seq_timer_t *tmr;
 
 	if (copy_from_user(&tempo, _tempo, sizeof(snd_seq_queue_tempo_t)))
 		return -EFAULT;
@@ -1824,7 +1825,7 @@ static int snd_seq_ioctl_get_queue_timer(client_t * client, snd_seq_queue_timer_
 {
 	snd_seq_queue_timer_t timer;
 	queue_t *queue;
-	timer_t *tmr;
+	seq_timer_t *tmr;
 
 	if (in_interrupt())
 		return -EBUSY;
@@ -1879,7 +1880,7 @@ static int snd_seq_ioctl_set_queue_timer(client_t * client, snd_seq_queue_timer_
 
 	if (snd_seq_queue_check_access(timer.queue, client->number)) {
 		queue_t *q;
-		timer_t *tmr;
+		seq_timer_t *tmr;
 
 		q = queueptr(timer.queue);
 		if (q == NULL)
