@@ -614,7 +614,7 @@ int snd_seq_queue_timer_open(int queueid)
 {
 	int result = 0;
 	queue_t *queue;
-	timer_t *tmr;
+	seq_timer_t *tmr;
 
 	queue = queueptr(queueid);
 	if (queue == NULL)
@@ -647,7 +647,7 @@ int snd_seq_queue_timer_open(int queueid)
 int snd_seq_queue_timer_close(int queueid)
 {
 	queue_t *queue;
-	timer_t *tmr;
+	seq_timer_t *tmr;
 
 	queue = queueptr(queueid);
 	if (queue == NULL)
@@ -818,7 +818,7 @@ void snd_seq_info_queues_read(snd_info_buffer_t * buffer, void *private_data)
 {
 	int bpm;
 	queue_t *q;
-	timer_t *tmr;
+	seq_timer_t *tmr;
 
 	read_lock(&queue_list_lock);
 	for (q = queue_list; q; q = q->next) {
