@@ -50,6 +50,7 @@ int snd_device_uid = 0;
 MODULE_AUTHOR("Jaroslav Kysela <perex@suse.cz>");
 MODULE_DESCRIPTION("Advanced Linux Sound Architecture driver for soundcards.");
 MODULE_SUPPORTED_DEVICE("sound");
+MODULE_LICENSE("GPL");
 MODULE_PARM(snd_major, "i");
 MODULE_PARM_DESC(snd_major, "Major # for sound driver. (116 by default)");
 MODULE_PARM(snd_cards_limit, "1-" __MODULE_STRING(SND_CARDS) "i");
@@ -614,17 +615,17 @@ EXPORT_SYMBOL(snd_register_oss_device);
 EXPORT_SYMBOL(snd_unregister_oss_device);
 #endif
   /* memory.c */
+#ifdef CONFIG_SND_DEBUG_MEMORY
 EXPORT_SYMBOL(snd_kmalloc);
-EXPORT_SYMBOL(snd_kcalloc);
+EXPORT_SYMBOL(snd_vmalloc);
+EXPORT_SYMBOL(snd_vfree);
 EXPORT_SYMBOL(_snd_kfree);
-#ifdef CONFIG_SND_DEBUG
 EXPORT_SYMBOL(_snd_magic_kmalloc);
 EXPORT_SYMBOL(_snd_magic_kcalloc);
 EXPORT_SYMBOL(_snd_magic_kfree);
 #endif
+EXPORT_SYMBOL(snd_kcalloc);
 EXPORT_SYMBOL(snd_kmalloc_strdup);
-EXPORT_SYMBOL(snd_vmalloc);
-EXPORT_SYMBOL(snd_vfree);
 EXPORT_SYMBOL(snd_malloc_pages);
 EXPORT_SYMBOL(snd_free_pages);
 EXPORT_SYMBOL(snd_dma_malloc);
@@ -654,10 +655,12 @@ EXPORT_SYMBOL(snd_device_free);
 EXPORT_SYMBOL(snd_device_register);
 EXPORT_SYMBOL(snd_device_unregister);
 EXPORT_SYMBOL(snd_device_free_all);
-  /* misc.c */
+#ifdef CONFIG_SND_ISA
+  /* isadma.c */
 EXPORT_SYMBOL(snd_dma_program);
 EXPORT_SYMBOL(snd_dma_disable);
 EXPORT_SYMBOL(snd_dma_residue);
+#endif /* CONFIG_SND_ISA */
   /* info.c */
 EXPORT_SYMBOL(snd_iprintf);
 EXPORT_SYMBOL(snd_info_get_line);
@@ -695,7 +698,8 @@ EXPORT_SYMBOL(snd_control_switch_new);
 EXPORT_SYMBOL(snd_control_switch_change);
   /* misc.c */
 EXPORT_SYMBOL(snd_task_name);
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0) && defined(CONFIG_PCI)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0)
+#ifdef CONFIG_PCI
 EXPORT_SYMBOL(snd_pci_compat_match_device);
 EXPORT_SYMBOL(snd_pci_compat_register_driver);
 EXPORT_SYMBOL(snd_pci_compat_unregister_driver);
@@ -704,11 +708,17 @@ EXPORT_SYMBOL(snd_pci_compat_get_flags);
 EXPORT_SYMBOL(snd_pci_compat_set_power_state);
 EXPORT_SYMBOL(snd_pci_compat_enable_device);
 EXPORT_SYMBOL(snd_pci_compat_find_capability);
+/*EXPORT_SYMBOL(snd_pci_compat_alloc_consistent);*/
+/*EXPORT_SYMBOL(snd_pci_compat_free_consistent);*/
+EXPORT_SYMBOL(snd_pci_compat_dma_supported);
+EXPORT_SYMBOL(snd_pci_compat_get_dma_mask);
+EXPORT_SYMBOL(snd_pci_compat_set_dma_mask);
 EXPORT_SYMBOL(snd_pci_compat_get_driver_data);
 EXPORT_SYMBOL(snd_pci_compat_set_driver_data);
-#endif
+#endif /* CONFIG_PCI */
 #ifdef CONFIG_PM
 EXPORT_SYMBOL(pm_register);
 EXPORT_SYMBOL(pm_unregister);
 EXPORT_SYMBOL(pm_send);
-#endif
+#endif /* CONFIG_PM */
+#endif /* LINUX_VERSION_CODE < 2.3.0 */
