@@ -225,6 +225,11 @@ int snd_switch_read1(snd_card_t *card, snd_switch_t *_switch)
 			sw.device = sw1.device;
 			sw.channel = sw1.channel;
 			memcpy(sw.name, sw1.name, sizeof(sw.name));
+			/* special case */
+			if (sw1.type == SND_SW_TYPE_LIST_ITEM) {
+				sw.type = SND_SW_TYPE_LIST_ITEM;
+				sw.low = sw.high = sw1.low;
+			}
 			err = ksw->get(list->desc, ksw, &sw);
 			break;
 		}
