@@ -278,7 +278,9 @@ static int snd_emu10k1_init(emu10k1_t * emu)
 
 	snd_emu10k1_intr_enable(emu, INTE_PCIERRORENABLE);
 
-	emu->reserved_page = snd_emu10k1_synth_alloc(emu, 4096);
+	emu->reserved_page = (emu10k1_memblk_t *)snd_emu10k1_synth_alloc(emu, 4096);
+	if (emu->reserved_page)
+		emu->reserved_page->map_locked = 1;
 	
 	return 0;
 }
@@ -320,7 +322,10 @@ static int snd_emu10k1_done(emu10k1_t * emu)
 	snd_emu10k1_ptr_write(emu, SOLEH, 0, 0);
 
 	/* remove reserved page */
-	snd_emu10k1_synth_free(emu, emu->reserved_page);
+	if (emu->reserved_page != NULL) {
+		snd_emu10k1_synth_free(emu, (snd_emux_memblk_t *)emu->reserved_page);
+		emu->reserved_page = NULL;
+	}
 
 	/* disable audio and lock cache */
 	outl(HCFG_LOCKSOUNDCACHE | HCFG_LOCKTANKCACHE | HCFG_MUTEBUTTONENABLE, emu->port + HCFG);
@@ -412,7 +417,7 @@ static void snd_emu10k1_ecard_write(emu10k1_t * emu, unsigned int value)
 {
 	unsigned short count;
 	unsigned int data;
-	unsigned int hc_port;
+	unsigned long hc_port;
 	unsigned int hc_value;
 
 	hc_port = emu->port + HCFG;
@@ -528,6 +533,10 @@ static int snd_emu10k1_free(emu10k1_t * emu)
 		snd_free_pages(emu->silent_page, EMUPAGESIZE);
 	if (emu->ptb_pages)
 		snd_free_pages((void *)emu->ptb_pages, 32 * 1024);
+	if (emu->page_ptr_table)
+		vfree(emu->page_ptr_table);
+	if (emu->page_addr_table)
+		vfree(emu->page_addr_table);
 	snd_magic_kfree(emu);
 	return 0;
 }
@@ -537,6 +546,7 @@ int snd_emu10k1_create(snd_card_t * card,
 		       snd_dma_t * dma1ptr,
 		       snd_dma_t * dma2ptr,
 		       snd_irq_t * irqptr,
+		       long max_cache_bytes,
 		       emu10k1_t ** remu)
 {
 	emu10k1_t *emu;
@@ -558,7 +568,10 @@ int snd_emu10k1_create(snd_card_t * card,
 	spin_lock_init(&emu->emu_lock);
 	spin_lock_init(&emu->voice_lock);
 	spin_lock_init(&emu->synth_lock);
+	spin_lock_init(&emu->memblk_lock);
 	init_MUTEX(&emu->ptb_lock);
+	INIT_LIST_HEAD(&emu->mapped_link_head);
+	INIT_LIST_HEAD(&emu->mapped_order_link_head);
 	emu->pci = pci;
 	emu->dma1ptr = dma1ptr;
 	emu->dma2ptr = dma2ptr;
@@ -566,25 +579,32 @@ int snd_emu10k1_create(snd_card_t * card,
 	emu->synth = NULL;
 	emu->get_synth_voice = NULL;
 	emu->port = pci_resource_start(pci, 0);
+	emu->max_cache_pages = max_cache_bytes >> PAGE_SHIFT;
 
-	emu->ptb_pages = snd_malloc_pages(32 * 1024, NULL, 0);
+	emu->ptb_pages = snd_malloc_pages(32 * 1024, NULL, GFP_KERNEL);
 	if (emu->ptb_pages == NULL || ((long)virt_to_bus((void *)emu->ptb_pages) & ~0x7fffffffUL)) {
 		snd_printk(__PRETTY_FUNCTION__ ": PTB pages ptr > 2GB limit, giving up\n");
 		snd_emu10k1_free(emu);
 		return -ENOMEM;
 	}
-	emu->silent_page = snd_malloc_pages(EMUPAGESIZE, NULL, 0);
+	emu->page_ptr_table = (void **)vmalloc(emu->max_cache_pages * sizeof(void*));
+	emu->page_addr_table = (unsigned long*)vmalloc(emu->max_cache_pages * sizeof(unsigned long));
+	if (emu->page_ptr_table == NULL || emu->page_addr_table == NULL) {
+		snd_emu10k1_free(emu);
+		return -ENOMEM;
+	}
+	emu->silent_page = snd_malloc_pages(EMUPAGESIZE, NULL, GFP_KERNEL);
 	if (emu->silent_page == NULL || ((long)virt_to_bus(emu->silent_page) & ~0x7fffffffUL)) {
 		snd_printk(__PRETTY_FUNCTION__ ": Silent page ptr > 2GB limit, giving up\n");
 		snd_emu10k1_free(emu);
 		return -ENOMEM;
 	}
-	emu->memhdr = snd_emux_memhdr_new(EMUPAGESIZE * MAXPAGES);
+	emu->memhdr = snd_emux_memhdr_new(emu->max_cache_pages * PAGE_SIZE);
 	if (emu->memhdr == NULL) {
 		snd_emu10k1_free(emu);
 		return -ENOMEM;
 	}
-	emu->memhdr->block_extra_size = sizeof(snd_emu10k1_memblk_arg_t);
+	emu->memhdr->block_extra_size = sizeof(emu10k1_memblk_t) - sizeof(snd_emux_memblk_t);
 
 	pci_set_master(pci);
 	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
@@ -652,6 +672,7 @@ EXPORT_SYMBOL(snd_emu10k1_synth_alloc);
 EXPORT_SYMBOL(snd_emu10k1_synth_free);
 EXPORT_SYMBOL(snd_emu10k1_synth_bzero);
 EXPORT_SYMBOL(snd_emu10k1_synth_copy_from_user);
+EXPORT_SYMBOL(snd_emu10k1_memblk_map);
 /* voice.c */
 EXPORT_SYMBOL(snd_emu10k1_voice_alloc);
 EXPORT_SYMBOL(snd_emu10k1_voice_free);
@@ -664,3 +685,4 @@ EXPORT_SYMBOL(snd_emu10k1_pcm_efx);
 /* io.c */
 EXPORT_SYMBOL(snd_emu10k1_ptr_read);
 EXPORT_SYMBOL(snd_emu10k1_ptr_write);
+MODULE_LICENSE("GPL");
