@@ -649,7 +649,7 @@ static int snd_emu10k1_playback_open(void *private_data,
 	epcm->type = PLAYBACK_EMUVOICE;
 	epcm->subchn = subchn;
 	epcm->memblk = memblk;
-	epcm->start_addr = memblk->offset;
+	epcm->start_addr = ((emu10k1_memblk_t *)memblk)->mapped_page << PAGE_SHIFT;
 	// emu10k1->pcm_mixer[subchn->number].number = emu->number;
 	// snd_emu10k1_pcm_mixer_build(emu, subchn->number);
 	/* FIXME: */
@@ -752,7 +752,7 @@ static int snd_emu10k1_capture_mic_open(void *private_data,
 		snd_pcm_dma_free(subchn);
 		return -ENOMEM;
 	}
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 	memcpy(runtime->hw, &snd_emu10k1_capture, sizeof(snd_emu10k1_capture));
 	runtime->hw->rates = SND_PCM_RATE_8000;
 	runtime->hw->min_rate = runtime->hw->max_rate = 8000;
@@ -807,7 +807,7 @@ static int snd_emu10k1_capture_efx_open(void *private_data,
 		snd_pcm_dma_free(subchn);
 		return -ENOMEM;
 	}
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 	memcpy(runtime->hw, &snd_emu10k1_capture, sizeof(snd_emu10k1_capture));
 	runtime->hw->rates = SND_PCM_RATE_48000;
 	runtime->hw->min_rate = runtime->hw->max_rate = 48000;
