@@ -62,6 +62,7 @@ static struct {
 	{	0x41445340,	"AD1881"			},
 	{	0x41445348,	"AD1881A"			},
 	{	0x41445360,	"AD1885"			},
+	{	0x41445361,	"AD1886"			},
 	{	0x414c4710,	"ALC200/200P"			},
 	{	0x43525903,	"CS4297"			},
 	{	0x43525913,	"CS4297A rev A"			},
@@ -77,10 +78,13 @@ static struct {
 	{	0x574d4c00,	"WM9701A"			},
 	{	0x574d4c03,	"WM9703/9704",			},
 	{	0x574d4c04,	"WM9704 (quad)",		},
+	{	0x83847600,	"STAC9700/83/84"		},
 	{	0x83847604,	"STAC9701/3/4/5"		},
 	{	0x83847605,	"STAC9704"			},
 	{	0x83847608,	"STAC9708/11"			},
 	{	0x83847609,	"STAC9721/23"			},
+	{	0x83847644,	"STAC9744"			},
+	{	0x83847656,	"STAC9756/57",			},
 	{	0, 		NULL				}
 };
 
@@ -136,6 +140,7 @@ static int snd_ac97_valid_reg(ac97_t *ac97, unsigned short reg)
 	case 0x41445340:	/* AD1881 */
 	case 0x41445348:	/* AD1881A */
 	case 0x41445360:	/* AD1885 */
+	case 0x41445361:	/* AD1886 */
 		if (reg >= 0x3a && reg <= 0x59)
 			return 0;
 		return 1;
@@ -593,7 +598,10 @@ static int snd_ac97_3d(snd_kmixer_element_t *element, int w_flag, struct snd_mix
 	if (ac97->id == 0x83847608) {	// Sigmatel 9708
 		depth = ac97->regs[AC97_3D_CONTROL] & ac97->max_3d;
 		depth_rear = (ac97->regs[AC97_3D_CONTROL] >> 2) & ac97->max_3d;
-	} else if (ac97->id == 0x83847609) {	// Sigmatel 9721/23
+	} else if (ac97->id == 0x83847609 ||	// Sigmatel 9721/23
+		   ac97->id == 0x83847600 ||
+		   ac97->id == 0x83847644 ||
+		   ac97->id == 0x83847656) {
 		depth = (ac97->regs[AC97_3D_CONTROL] >> ac97->shift_3d) & ac97->max_3d;
 	} else {
 		center = ((ac97->regs[AC97_3D_CONTROL] >> 8) >> ac97->shift_3d) & ac97->max_3d;
@@ -604,7 +612,10 @@ static int snd_ac97_3d(snd_kmixer_element_t *element, int w_flag, struct snd_mix
 		if (ac97->id == 0x83847608) {	// Sigmatel 9708
 			effect1->depth = depth;
 			effect1->depth_rear = depth_rear;
-		} else if (ac97->id == 0x83847609) {	// Sigmatel 9721/23
+		} else if (ac97->id == 0x83847609 ||	// Sigmatel 9721/23
+			   ac97->id == 0x83847600 ||
+			   ac97->id == 0x83847644 ||
+			   ac97->id == 0x83847656) {
 			effect1->wide = depth;
 		} else {
 			effect1->center = center;
@@ -615,7 +626,10 @@ static int snd_ac97_3d(snd_kmixer_element_t *element, int w_flag, struct snd_mix
 		if (ac97->id == 0x83847608) {	// Sigmatel 9708
 			change |= effect1->depth != depth ||
 				   effect1->depth_rear != depth_rear;				
-		} else if (ac97->id == 0x83847609) {	// Sigmatel 9721/23
+		} else if (ac97->id == 0x83847609 ||	// Sigmatel 9721/23
+			   ac97->id == 0x83847600 ||
+			   ac97->id == 0x83847644 ||
+			   ac97->id == 0x83847656) {
 			change |= effect1->wide != depth;
 		} else {
 			change |= effect1->center != center ||
@@ -627,7 +641,10 @@ static int snd_ac97_3d(snd_kmixer_element_t *element, int w_flag, struct snd_mix
 		if (ac97->id == 0x83847608) {	// Sigmatel 9708
 			ac97->regs[AC97_3D_CONTROL] &= ~((ac97->max_3d << 2) | ac97->max_3d);
 			ac97->regs[AC97_3D_CONTROL] |=	(effect1->depth_rear << 2) | effect1->depth;
-		} else if (ac97->id == 0x83847609) {	// Sigmatel 9721
+		} else if (ac97->id == 0x83847609 ||	// Sigmatel 9721
+			   ac97->id == 0x83847600 ||
+			   ac97->id == 0x83847644 ||
+			   ac97->id == 0x83847656) {
 			ac97->regs[AC97_3D_CONTROL] &= ~(ac97->max_3d << ac97->shift_3d);
 			ac97->regs[AC97_3D_CONTROL] |= effect1->wide << ac97->shift_3d;
 		} else {
@@ -854,7 +871,10 @@ static void snd_ac97_change_3d_params(ac97_t * ac97)
 		ac97->max_3d = 3;
 		ac97->shift_3d = 0;	// not used.
 		snd_ac97_write(ac97, AC97_3D_CONTROL, 0x000f);
-	} else if (ac97->id == 0x83847609) {	// Sigmatel 9721/23
+	} else if (ac97->id == 0x83847609 ||	// Sigmatel 9721/23
+		   ac97->id == 0x83847600 ||
+		   ac97->id == 0x83847644 ||
+		   ac97->id == 0x83847656) {
 		ac97->max_3d = 3;
 		// manual says that DP0-1 bits are valid,
 		// but it doesn't seem true (maybe some early revisions?)
@@ -1626,7 +1646,10 @@ static int snd_ac97_mixer_build(snd_kmixer_t * mixer, ac97_t * ac97, int pcm_cou
 			info.effect = SND_MIXER_EFF1_SW | SND_MIXER_EFF1_DEPTH | SND_MIXER_EFF1_DEPTH_REAR;
 			snd_ac97_change_3d_params(ac97);
 			info.max_depth = info.max_depth_rear = ac97->max_3d;
-		} else if (ac97->id == 0x83847609) {	// Sigmatel 9721/23
+		} else if (ac97->id == 0x83847609 || // Sigmatel 9721/23
+			   ac97->id == 0x83847600 ||
+			   ac97->id == 0x83847644 ||
+			   ac97->id == 0x83847656) {
 			info.effect = SND_MIXER_EFF1_SW | SND_MIXER_EFF1_WIDE;
 			snd_ac97_change_3d_params(ac97);
 			info.max_wide = ac97->max_3d;
@@ -1937,10 +1960,10 @@ int snd_ac97_mixer(snd_card_t * card, int device,
 		return -EIO;
 	}
 	ac97->caps = snd_ac97_read(ac97, AC97_RESET);
-	snd_ac97_write(ac97, AC97_POWERDOWN, 0);	/* nothing should be in powerdown mode */
+	snd_ac97_write(ac97, AC97_POWERDOWN, 0);	/* nothing should be in the powerdown mode */
 	snd_ac97_write(ac97, AC97_RESET, 0);		/* reset to defaults */
 	udelay(100);
-	snd_ac97_write(ac97, AC97_POWERDOWN, 0);	/* nothing should be in powerdown mode */
+	snd_ac97_write(ac97, AC97_POWERDOWN, 0);	/* nothing should be in the powerdown mode */
 	snd_ac97_write(ac97, AC97_GENERAL_PURPOSE, 0);
 	if (ac97->init)
 		ac97->init(ac97->private_data, ac97);
@@ -1952,7 +1975,9 @@ int snd_ac97_mixer(snd_card_t * card, int device,
 		if (snd_ac97_try_switch(ac97, &snd_ac97_switches[idx]))
 			snd_mixer_switch_new(mixer, &snd_ac97_switches[idx], ac97);
 	}
-	if (ac97->id == 0x83847608 || ac97->id == 0x83847609) {
+	if (ac97->id == 0x83847608 || ac97->id == 0x83847609 ||
+	    ac97->id == 0x83847600 || ac97->id == 0x83847644 ||
+	    ac97->id == 0x83847656) {
 		ac97->regs[AC97_SIGMATEL_ANALOG] = snd_ac97_read(ac97, AC97_SIGMATEL_ANALOG);
 		for (idx = 0; idx < AC97_SIGMATEL_SWITCHES; idx++)
 			if (snd_ac97_try_switch(ac97, &snd_ac97_sigmatel_switches[idx]))
@@ -2087,7 +2112,7 @@ static void snd_ac97_proc_regs_read(snd_info_buffer_t * buffer, void *private_da
 	ac97_t *ac97 = snd_magic_cast(ac97_t, private_data, );
 
 	for (reg = 0; reg < 0x80; reg += 2) {
-		val = snd_ac97_read_lock(ac97, reg);
+		val = snd_ac97_read(ac97, reg);
 		snd_iprintf(buffer, "%02x = %04x\n", reg, val);
 	}
 }
@@ -2162,6 +2187,14 @@ static int snd_ac97_Sig8384_7609(ac97_t * ac97)
 		}
 		return 1;
 	}
+	if (ac97->id == 0x83847644 || ac97->id == 0x83847656) {
+		// patch for SigmaTel
+		snd_ac97_write(ac97, AC97_SIGMATEL_CIC1, 0xabba);
+		snd_ac97_write(ac97, AC97_SIGMATEL_CIC2, 0x0000);
+		snd_ac97_write(ac97, AC97_SIGMATEL_BIAS1, 0xabba);
+		snd_ac97_write(ac97, AC97_SIGMATEL_BIAS2, 0x0002);
+		return 1;
+	}
 	return 0;
 }
 
@@ -2202,8 +2235,8 @@ static int snd_ac97_Wolfson574D_4C0X(ac97_t * ac97)
 		// patch for DVD noise
 		snd_ac97_write(ac97, 0x5a, 0x0200);
 
-		// init vol as PCM vol
-		snd_ac97_write(ac97, 0x70, snd_ac97_read(ac97, AC97_PCM));
+		// init vol
+		snd_ac97_write(ac97, 0x70, 0x0808);
 
 		snd_ac97_write(ac97, AC97_SURROUND_MASTER, 0x0000);
 		return 1;
@@ -2225,18 +2258,6 @@ static int snd_ac97_TriTech5452_4108(ac97_t * ac97)
 	return 0;
 }
 
-//---------------------------------------------------------------------------
-static int snd_ac97_AD1885(ac97_t * ac97)
-{
-	// detect the Analog Devices AD1885
-	if (ac97->id == 0x41445460) {
-		// enable EAPD
-		snd_ac97_write(ac97, AC97_POWERDOWN, snd_ac97_read(ac97, AC97_POWERDOWN) | 0x8000);
-		return 1;
-	}
-	return 0;
-}
-
 static void snd_ac97_chip_init(ac97_t * ac97)
 {
 	if (snd_ac97_TriTech5452_4108(ac97))	// patch for TriTech 5452 and 4108
@@ -2247,10 +2268,33 @@ static void snd_ac97_chip_init(ac97_t * ac97)
 		return;
 	if (snd_ac97_Wolfson574D_4C0X(ac97))	// patch for Wolfson
 		return;
-	if (snd_ac97_AD1885(ac97))		// patch for AD1885
-		return;
 }
 
+#ifdef CONFIG_PM
+/*
+ * general resume procedure
+ */
+void snd_ac97_resume(ac97_t *ac97)
+{
+	int i;
+
+	snd_ac97_write(ac97, AC97_POWERDOWN, 0);	/* nothing should be in the powerdown mode */
+	snd_ac97_write(ac97, AC97_RESET, 0);		/* reset to defaults */
+	udelay(100);
+	snd_ac97_write(ac97, AC97_POWERDOWN, 0);	/* nothing should be in the powerdown mode */
+	snd_ac97_write(ac97, AC97_GENERAL_PURPOSE, 0);
+	if (ac97->init)
+		ac97->init(ac97->private_data, ac97);
+
+	snd_ac97_chip_init(ac97);
+
+	/* restore ac97 status */
+	for (i = 2; i < 0x26 ; i += 2)
+		snd_ac97_write(ac97, i, ac97->regs[i]);
+}
+#endif
+
+
 /*
  *  Exported symbols
  */
@@ -2261,6 +2305,9 @@ EXPORT_SYMBOL(snd_ac97_write_lock);
 EXPORT_SYMBOL(snd_ac97_write_bitmask_lock);
 EXPORT_SYMBOL(snd_ac97_read_lock);
 EXPORT_SYMBOL(snd_ac97_mixer);
+#ifdef CONFIG_PM
+EXPORT_SYMBOL(snd_ac97_resume);
+#endif
 
 /*
  *  INIT part
@@ -2277,3 +2324,4 @@ static void __exit alsa_ac97_exit(void)
 
 module_init(alsa_ac97_init)
 module_exit(alsa_ac97_exit)
+MODULE_LICENSE("GPL");
