@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Takashi Iwai <iwai@ww.uni-erlangen.de>
+ *  Copyright (C) 2000 Takashi Iwai <tiwai@suse.de>
  *
  *  Routines for control of EMU WaveTable chip
  *
@@ -123,6 +123,15 @@ int snd_emux_free(snd_emux_t *emu)
 }
 
 
+EXPORT_SYMBOL(snd_emux_new);
+EXPORT_SYMBOL(snd_emux_register);
+EXPORT_SYMBOL(snd_emux_free);
+
+EXPORT_SYMBOL(snd_emux_terminate_all);
+EXPORT_SYMBOL(snd_emux_lock_voice);
+EXPORT_SYMBOL(snd_emux_unlock_voice);
+
+
 /*
  *  INIT part
  */
@@ -138,3 +147,4 @@ static void __exit alsa_emux_exit(void)
 
 module_init(alsa_emux_init)
 module_exit(alsa_emux_exit)
+MODULE_LICENSE("GPL");
