@@ -104,12 +104,19 @@ snd_emux_note_on(void *p, int note, int vel, snd_midi_channel_t *chan)
 		vp->note = note;
 		vp->velocity = vel;
 		vp->zone = table[i];
+		if (vp->zone->sample)
+			vp->block = vp->zone->sample->block;
+		else
+			vp->block = NULL;
 
 		setup_voice(vp);
 
-		if (emu->ops.prepare)
-			emu->ops.prepare(vp);
 		vp->state = SND_EMUX_ST_STANDBY;
+		if (emu->ops.prepare) {
+			vp->state = SND_EMUX_ST_OFF;
+			if (emu->ops.prepare(vp) >= 0)
+				vp->state = SND_EMUX_ST_STANDBY;
+		}
 	}
 
 	/* start envelope now */
@@ -449,6 +456,8 @@ terminate_voice(snd_emux_t *emu, snd_emux_voice_t *vp, int free)
 	vp->time = emu->use_time++;
 	vp->chan = NULL;
 	vp->port = NULL;
+	vp->zone = NULL;
+	vp->block = NULL;
 	vp->state = SND_EMUX_ST_OFF;
 	if (free && emu->ops.free_voice)
 		emu->ops.free_voice(vp);
