@@ -34,14 +34,14 @@ static void snd_mpu401_uart_output_write(snd_rawmidi_t * rmidi, mpu401_t * mpu);
 
  */
 
-static void snd_mpu401_uart_clear_rx(mpu401_t *mpu)
+static void snd_mpu401_uart_clear_rx(mpu401_t *mpu, char *where)
 {
 	int timeout = 100000;
 	for (; timeout > 0 && !(inb(MPU401C(mpu)) & 0x40); timeout--)
 		inb(MPU401D(mpu));
 #ifdef CONFIG_SND_DEBUG
 	if (timeout <= 0)
-		snd_printk("cmd: clear rx timeout (status = 0x%x)\n", inb(MPU401C(mpu)));
+		snd_printk("cmd: clear rx timeout (status = 0x%x) at %s\n", inb(MPU401C(mpu)), where);
 #endif
 }
 
@@ -55,7 +55,7 @@ void snd_mpu401_uart_interrupt(snd_rawmidi_t * rmidi)
 	if (mpu->mode & MPU401_MODE_INPUT)
 		snd_mpu401_uart_input_read(rmidi, mpu);
 	else
-		snd_mpu401_uart_clear_rx(mpu);
+		snd_mpu401_uart_clear_rx(mpu, "uart_intr");
 	/* ok. for better Tx performance try do some output when input is done */
 	if (mpu->mode & MPU401_MODE_OUTPUT)
 		snd_mpu401_uart_output_write(rmidi, mpu);
@@ -75,7 +75,7 @@ static void snd_mpu401_uart_timer(unsigned long data)
 		if (mpu->mode & MPU401_MODE_INPUT)
 			snd_mpu401_uart_input_read(mpu->rmidi, mpu);
 		else
-			snd_mpu401_uart_clear_rx(mpu);
+			snd_mpu401_uart_clear_rx(mpu, "uart_timer");
 		if (mpu->mode & MPU401_MODE_OUTPUT)
 			snd_mpu401_uart_output_write(mpu->rmidi, mpu);
 	}
@@ -123,7 +123,7 @@ static void snd_mpu401_uart_cmd(mpu401_t * mpu, unsigned char cmd, int ack)
 	spin_lock_irqsave(&mpu->input_lock, flags);
 	if (mpu->hardware != MPU401_HW_TRID4DWAVE) {
 		outb(0x00, MPU401D(mpu));
-		snd_mpu401_uart_clear_rx(mpu);
+		/*snd_mpu401_uart_clear_rx(mpu, "uart_cmd");*/
 	}
 	/* ok. standard MPU-401 initialization */
 	if (mpu->hardware != MPU401_HW_SB) {
@@ -411,3 +411,4 @@ static void __exit alsa_mpu401_uart_exit(void)
 
 module_init(alsa_mpu401_uart_init)
 module_exit(alsa_mpu401_uart_exit)
+MODULE_LICENSE("GPL");
