@@ -25,91 +25,21 @@
 
 #define SND_MAIN_OBJECT_FILE
 #include "../../include/driver.h"
+#include "../../include/minors.h"
 #include "../../include/opl3.h"
 
-/*
- *    There is 18 possible 2 OP voices
- *      (9 in the left and 9 in the right).
- *      The first OP is the modulator and 2nd is the carrier.
- *
- *      The first three voices in the both sides may be connected
- *      with another voice to a 4 OP voice. For example voice 0
- *      can be connected with voice 3. The operators of voice 3 are
- *      used as operators 3 and 4 of the new 4 OP voice.
- *      In this case the 2 OP voice number 0 is the 'first half' and
- *      voice 3 is the second.
- */
 
-#if 0
-
-#define OPL3_USE_LEFT	0
-#define OPL3_USE_RIGHT	1
-
-static struct snd_opl3_physical_voice_info snd_opl3_pv_map[18] =
-{
-/*       No Mode Side           OP1     OP2     OP3   OP4       */
-/*      ---------------------------------------------------     */
-	{0, 2, OPL3_USE_LEFT,
-	 {0x00, 0x03, 0x08, 0x0b}},
-	{1, 2, OPL3_USE_LEFT,
-	 {0x01, 0x04, 0x09, 0x0c}},
-	{2, 2, OPL3_USE_LEFT,
-	 {0x02, 0x05, 0x0a, 0x0d}},
-
-	{3, 2, OPL3_USE_LEFT,
-	 {0x08, 0x0b, 0x00, 0x00}},
-	{4, 2, OPL3_USE_LEFT,
-	 {0x09, 0x0c, 0x00, 0x00}},
-	{5, 2, OPL3_USE_LEFT,
-	 {0x0a, 0x0d, 0x00, 0x00}},
-
-	{6, 2, OPL3_USE_LEFT,
-	 {0x10, 0x13, 0x00, 0x00}},	/* Used by percussive voices */
-	{7, 2, OPL3_USE_LEFT,
-	 {0x11, 0x14, 0x00, 0x00}},	/* if the percussive mode */
-	{8, 2, OPL3_USE_LEFT,
-	 {0x12, 0x15, 0x00, 0x00}},	/* is selected */
-
-	{0, 2, OPL3_USE_RIGHT,
-	 {0x00, 0x03, 0x08, 0x0b}},
-	{1, 2, OPL3_USE_RIGHT,
-	 {0x01, 0x04, 0x09, 0x0c}},
-	{2, 2, OPL3_USE_RIGHT,
-	 {0x02, 0x05, 0x0a, 0x0d}},
-
-	{3, 2, OPL3_USE_RIGHT,
-	 {0x08, 0x0b, 0x00, 0x00}},
-	{4, 2, OPL3_USE_RIGHT,
-	 {0x09, 0x0c, 0x00, 0x00}},
-	{5, 2, OPL3_USE_RIGHT,
-	 {0x0a, 0x0d, 0x00, 0x00}},
-
-	{6, 2, OPL3_USE_RIGHT,
-	 {0x10, 0x13, 0x00, 0x00}},
-	{7, 2, OPL3_USE_RIGHT,
-	 {0x11, 0x14, 0x00, 0x00}},
-	{8, 2, OPL3_USE_RIGHT,
-	 {0x12, 0x15, 0x00, 0x00}}
-};
-
-#endif
-
-/*
-
- */
-
-static void snd_opl3_command(opl3_t * opl3,
-			     unsigned int cmd, unsigned char val)
+void snd_opl3_command(opl3_t * opl3, unsigned short cmd, unsigned char val)
 {
 	unsigned long flags;
-	unsigned short port;
+	unsigned long port;
 
 	/*
 	 * The original 2-OP synth requires a quite long delay after writing to a
 	 * register. The OPL-3 survives with just two INBs
 	 */
 
-	port = cmd & OPL3_RIGHT ? opl3->r_port : opl3->l_port;
+	port = (cmd & OPL3_RIGHT) ? opl3->r_port : opl3->l_port;
 
 	spin_lock_irqsave(&opl3->reg_lock, flags);
 
@@ -122,7 +52,7 @@ static void snd_opl3_command(opl3_t * opl3,
 		inb(port);
 	}
 
-	outb((unsigned char) (val & 0xff), port + 1);
+	outb((unsigned char) val, port + 1);
 
 	if (opl3->hardware == OPL3_HW_OPL2) {
 		udelay(30);
@@ -134,10 +64,6 @@ static void snd_opl3_command(opl3_t * opl3,
 	spin_unlock_irqrestore(&opl3->reg_lock, flags);
 }
 
-/*
-
- */
-
 static int snd_opl3_detect(opl3_t * opl3)
 {
 	/*
@@ -154,10 +80,12 @@ static int snd_opl3_detect(opl3_t * opl3)
 	unsigned char stat1, stat2, signature;
 
 	/* some hardware doesn't support timers */
-	if (opl3->hardware == OPL3_HW_OPL3_SV ||
-	    opl3->hardware == OPL3_HW_OPL3_CS ||
-	    opl3->hardware == OPL3_HW_OPL3_FM801)
+	switch (opl3->hardware) {
+	case OPL3_HW_OPL3_SV:
+	case OPL3_HW_OPL3_CS:
+	case OPL3_HW_OPL3_FM801:
 		return 0;
+	}
 	/* Reset timers 1 and 2 */
 	snd_opl3_command(opl3, OPL3_LEFT | OPL3_REG_TIMER_CONTROL, OPL3_TIMER1_MASK | OPL3_TIMER2_MASK);
 	/* Reset the IRQ of the FM chip */
@@ -183,15 +111,13 @@ static int snd_opl3_detect(opl3_t * opl3)
 		snd_printd("OPL3: stat2 = 0x%x\n", stat2);
 		return -ENODEV;
 	}
-	/* There is a FM chip in this address. Detect the type (OPL2 to OPL4) */
+	/* There is a FM chip on this address. Detect the type (OPL2 to OPL4) */
 	if (opl3->hardware != OPL3_HW_AUTO)
 		return 0;
 
 	if (signature == 0x06) {	/* OPL2 */
 		opl3->hardware = OPL3_HW_OPL2;
 	} else {
-		unsigned char tmp;
-
 		opl3->hardware = OPL3_HW_OPL3;
 		/*
 		 * Detect availability of OPL4 (_experimental_). Works probably
@@ -199,12 +125,14 @@ static int snd_opl3_detect(opl3_t * opl3)
 		 * of the chip may not be connected to the PC bus at all.
 		 */
 		snd_opl3_command(opl3, OPL3_RIGHT | OPL3_REG_MODE, 0x00);
-		snd_opl3_command(opl3, OPL3_RIGHT | OPL3_REG_MODE, OPL3_MODE2_ENABLE | OPL3_MODE3_ENABLE);
-		if ((tmp = inb(opl3->l_port)) == 0x02) {	/* Have a OPL4 */
+		snd_opl3_command(opl3, OPL3_RIGHT | OPL3_REG_MODE, OPL3_OPL3_ENABLE | OPL3_OPL4_ENABLE);
+		if (inb(opl3->l_port) == 0x02) {	/* Have a OPL4 */
 			opl3->hardware = OPL3_HW_OPL4;
 		}
-		snd_opl3_command(opl3, OPL3_RIGHT | OPL3_REG_MODE, 0x00);
+		snd_opl3_command(opl3, OPL3_RIGHT | OPL3_REG_MODE, 0x00);	/* Enter OPL2 mode */
 	}
+	snd_opl3_command(opl3, OPL3_LEFT | OPL3_REG_TEST, OPL3_ENABLE_WAVE_SELECT);
+	snd_opl3_command(opl3, OPL3_LEFT | OPL3_REG_PERCUSSION, 0x00);	/* Melodic mode */
 
 	return 0;
 }
@@ -359,19 +287,25 @@ void snd_opl3_interrupt(snd_hwdep_t * hw)
 
 int snd_opl3_new(snd_card_t * card,
 		 int device,
-		 unsigned short l_port,
-		 unsigned short r_port,
+		 unsigned long l_port,
+		 unsigned long r_port,
 		 unsigned short hardware,
 		 int timer_dev,
 		 snd_hwdep_t ** rhwdep)
 {
 	opl3_t *opl3;
 	snd_hwdep_t *hw;
-	int err;
+	int i, err;
 
 	*rhwdep = NULL;
 	if ((err = snd_hwdep_new(card, "OPL2/OPL3", device, &hw)) < 0)
 		return err;
+#ifdef CONFIG_SND_OSSEMUL
+	if (device == 0) {
+		hw->oss_type = SND_OSS_DEVICE_TYPE_DMFM;
+		sprintf(hw->oss_dev, "dmfm%i", card->number);
+	}
+#endif
 	opl3 = snd_magic_kcalloc(opl3_t, 0, GFP_KERNEL);
 	if (opl3 == NULL) {
 		snd_device_free(card, hw);
@@ -383,14 +317,18 @@ int snd_opl3_new(snd_card_t * card,
 	opl3->timer_dev = timer_dev;
 	strcpy(hw->name, hw->id);
 	hw->private_data = opl3;
-	hw->private_free = _snd_magic_kfree;
+	hw->private_free = (snd_kfree_type)_snd_magic_kfree;
 	spin_lock_init(&opl3->reg_lock);
 	spin_lock_init(&opl3->timer_lock);
 	if (snd_opl3_detect(opl3) < 0) {
 		snd_device_free(card, hw);
-		snd_printd("opl3: OPL2/3 chip not detected at 0x%x/0x%x\n", opl3->l_port, opl3->r_port);
+		snd_printd("opl3: OPL2/3 chip not detected at 0x%lx/0x%lx\n",
+			   opl3->l_port, opl3->r_port);
 		return -ENODEV;
 	}
+	for (i = 0; i < MAX_OPL2_VOICES; i++)
+		opl3->voice[i] = 0x02;	/* Mark available 2-op voices */
+	init_MUTEX(&opl3->access_mutex);
 	switch (opl3->hardware & OPL3_HW_MASK) {
 	case OPL3_HW_OPL2:
 		strcpy(hw->name, "OPL2 FM");
@@ -407,6 +345,11 @@ int snd_opl3_new(snd_card_t * card,
 	}
 	if (timer_dev >= 0)
 		snd_opl3_timers_init(card, opl3, timer_dev);
+
+	/* operators - only ioctl */
+	hw->ops.open = snd_opl3_open;
+	hw->ops.ioctl = snd_opl3_ioctl;
+	hw->ops.release = snd_opl3_release;
 	*rhwdep = hw;
 	return 0;
 }
@@ -429,3 +372,4 @@ static void __exit alsa_opl3_exit(void)
 
 module_init(alsa_opl3_init)
 module_exit(alsa_opl3_exit)
+MODULE_LICENSE("GPL");
