@@ -4,7 +4,7 @@
  *	to accept soundfont patches.
  *
  *  Copyright (C) 1999 Steve Ratcliffe
- *  Copyright (c) 1999-2000 Takashi Iwai <iwai@ww.uni-erlangen.de>
+ *  Copyright (c) 1999-2000 Takashi Iwai <tiwai@suse.de>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ static snd_sf_sample_t *sf_sample_new(snd_sf_list_t *sflist, snd_soundfont_t *sf
 static void sf_sample_delete(snd_sf_list_t *sflist, snd_soundfont_t *sf, snd_sf_sample_t *sp);
 static int load_map(snd_sf_list_t *sflist, const void *data, int count);
 static int load_info(snd_sf_list_t *sflist, const void *data, long count);
+static int remove_info(snd_sf_list_t *sflist, snd_soundfont_t *sf, int bank, int instr);
 static void init_voice_info(soundfont_voice_info_t *avp);
 static void init_voice_parm(soundfont_voice_parm_t *pp);
 static snd_sf_sample_t *set_sample(snd_soundfont_t *sf, soundfont_voice_info_t *avp);
@@ -178,6 +179,21 @@ snd_soundfont_load(snd_sf_list_t *sflist, const void *data, long count, int clie
 	case SND_SFNT_PROBE_DATA:
 		rc = probe_data(sflist, patch.optarg);
 		break;
+	case SND_SFNT_REMOVE_INFO:
+		/* patch must be opened */
+		if (sflist->currsf) {
+			snd_printk("soundfont: remove_info: patch not opened\n");
+			rc = -EINVAL;
+		} else {
+			int bank, instr;
+			bank = ((unsigned short)patch.optarg >> 8) & 0xff;
+			instr = (unsigned short)patch.optarg & 0xff;
+			if (! remove_info(sflist, sflist->currsf, bank, instr))
+				rc = -EINVAL;
+			else
+				rc = 0;
+		}
+		break;
 	}
 	unlock_preset(sflist);
 
@@ -190,7 +206,7 @@ static inline int
 is_special_type(int type)
 {
 	type &= 0x0f;
-	return (type == SND_SFNT_PAT_TYPE_MISC ||
+	return (type == SND_SFNT_PAT_TYPE_GUS ||
 		type == SND_SFNT_PAT_TYPE_MAP);
 }
 
@@ -443,6 +459,34 @@ load_map(snd_sf_list_t *sflist, const void *data, int count)
 }
 
 
+/* remove the present instrument layers */
+static int
+remove_info(snd_sf_list_t *sflist, snd_soundfont_t *sf, int bank, int instr)
+{
+	snd_sf_zone_t *prev, *next, *p;
+	int removed = 0;
+
+	prev = NULL;
+	for (p = sf->zones; p; p = next) {
+		next = p->next;
+		if (! p->mapped &&
+		    p->bank == bank && p->instr == instr) {
+			/* remove this layer */
+			if (prev)
+				prev->next = next;
+			else
+				sf->zones = next;
+			removed++;
+			kfree(p);
+		} else
+			prev = p;
+	}
+	if (removed)
+		rebuild_presets(sflist);
+	return removed;
+}
+
+
 /*
  * Read an info record from the user buffer and save it on the current
  * open soundfont.
@@ -451,7 +495,7 @@ static int
 load_info(snd_sf_list_t *sflist, const void *data, long count)
 {
 	snd_soundfont_t *sf;
-	snd_sf_zone_t *zone, *prev;
+	snd_sf_zone_t *zone;
 	soundfont_voice_rec_hdr_t hdr;
 	int i;
 
@@ -483,6 +527,23 @@ load_info(snd_sf_list_t *sflist, const void *data, long count)
 		return -EINVAL;
 	}
 
+	switch (hdr.write_mode) {
+	case SND_SFNT_WR_EXCLUSIVE:
+		/* exclusive mode - if the instrument already exists,
+		   return error */
+		for (zone = sf->zones; zone; zone = zone->next) {
+			if (!zone->mapped &&
+			    zone->bank == hdr.bank &&
+			    zone->instr == hdr.instr)
+				return -EINVAL;
+		}
+		break;
+	case SND_SFNT_WR_REPLACE:
+		/* replace mode - remove the instrument if it already exists */
+		remove_info(sflist, sf, hdr.bank, hdr.instr);
+		break;
+	}
+
 	for (i = 0; i < hdr.nvoices; i++) {
 		snd_sf_zone_t tmpzone;
 
@@ -501,40 +562,6 @@ load_info(snd_sf_list_t *sflist, const void *data, long count)
 		if (tmpzone.v.mode & SND_SFNT_MODE_INIT_PARM)
 			init_voice_parm(&tmpzone.v.parm);
 
-		/* look for the existing identical zone */
-		prev = NULL;
-		for (zone = sf->zones; zone; prev = zone, zone = zone->next) {
-			if (zone->mapped ||
-			    zone->bank != tmpzone.bank ||
-			    zone->instr != tmpzone.instr ||
-			    zone->v.sample != tmpzone.v.sample)
-				continue;
-			/* this is a dirty code..
-			 * start, end, loopstart, loopend may be
-			 * modified after linking to the sample.
-			 * so, we compare only from rate_offset to the
-			 * end of structure.
-			 */
-#define xoffsetof(type,tag)	((long)(&((type)NULL)->tag) - (long)(NULL))
-#define ZONE_COMP_SIZE	(sizeof(soundfont_voice_info_t) - xoffsetof(soundfont_voice_info_t*, rate_offset))
-			tmpzone.v.sample_mode = zone->v.sample_mode;
-			if (memcmp(&zone->v.rate_offset, &tmpzone.v.rate_offset,
-				   ZONE_COMP_SIZE) == 0)
-				break;
-		}
-
-		if (zone) {
-			/* the identical zone is found. relink it */
-			if (prev) {
-				prev->next = zone->next;
-				zone->next = sf->zones;
-				sf->zones = zone;
-			}
-			/* update the counter */
-			set_zone_counter(sflist, sf, zone);
-			continue;
-		}
-
 		/* create a new zone */
 		if ((zone = sf_zone_new(sflist, sf)) == NULL) {
 			return -ENOMEM;
@@ -906,7 +933,7 @@ load_guspatch(snd_sf_list_t *sflist, const char *data, long count, int client)
 	count -= sizeof(patch);
 	data += sizeof(patch);
 
-	sf = newsf(sflist, SND_SFNT_PAT_TYPE_MISC|SND_SFNT_PAT_SHARED, NULL);
+	sf = newsf(sflist, SND_SFNT_PAT_TYPE_GUS|SND_SFNT_PAT_SHARED, NULL);
 	if (sf == NULL)
 		return -ENOMEM;
 	if ((smp = sf_sample_new(sflist, sf)) == NULL)
