@@ -646,7 +646,7 @@ static int snd_uart16550_register_resources(snd_uart16550_t * uart)
 		return -EBUSY;
 	}
 	if (uart->irq_number >= 0) {
-		int possible_numbers[] = {3, 4, 5, 7, 9, 10, 11, 14, 15, -1};
+		static long possible_numbers[] = {3, 4, 5, 7, 9, 10, 11, 14, 15, -1};
 		snd_printd("snd_uart16550_register_resources requesting irq=%d\n",
 			   uart->irq_number);
 		if (snd_register_interrupt(uart->card, "serial MIDI(uart16550A)",
@@ -780,3 +780,4 @@ static void __exit alsa_uart16550_exit(void)
 
 module_init(alsa_uart16550_init)
 module_exit(alsa_uart16550_exit)
+MODULE_LICENSE("GPL");
