@@ -524,7 +524,7 @@ static int snd_ad1816a_playback_open(void *private_data,
 			sizeof(*runtime->hw), GFP_KERNEL)))
 		return -ENOMEM;
 	memcpy(runtime->hw, &snd_ad1816a_playback, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 
 	snd_pcm_set_sync(subchn);
 	snd_pcm_set_mixer(subchn, codec->mixer->device, codec->me_playback);
@@ -548,7 +548,7 @@ static int snd_ad1816a_capture_open(void *private_data,
 			sizeof(*runtime->hw), GFP_KERNEL)))
 		return -ENOMEM;
 	memcpy(runtime->hw, &snd_ad1816a_capture, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 
 	snd_pcm_set_sync(subchn);
 	snd_pcm_set_mixer(subchn, codec->mixer->device, codec->me_capture);
@@ -1930,3 +1930,4 @@ static void __exit alsa_ad1816a_exit(void)
 module_init(alsa_ad1816a_init)
 module_exit(alsa_ad1816a_exit)
 
+MODULE_LICENSE("GPL");
