@@ -282,7 +282,7 @@ void snd_cs4231_mce_up(cs4231_t * codec)
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
 }
 
-void snd_cs4231_mce_down(cs4231_t * codec)
+static void __snd_cs4231_mce_down(cs4231_t * codec, int busywait)
 {
 	unsigned long flags;
 	int timeout;
@@ -290,9 +290,6 @@ void snd_cs4231_mce_down(cs4231_t * codec)
 
 	spin_lock_irqsave(&codec->reg_lock, flags);
 	snd_cs4231_busy_wait(codec);
-#if 0
-	printk("(1) timeout = %i\n", timeout);
-#endif
 #ifdef CONFIG_SND_DEBUG
 	if (inb(CS4231P(codec, REGSEL)) & CS4231_INIT)
 		snd_printk("cs4231_mce_down [0x%lx] - auto calibration time out (0)\n", CS4231P(codec, REGSEL));
@@ -313,23 +310,24 @@ void snd_cs4231_mce_down(cs4231_t * codec)
 
 	for (timeout = 500; timeout > 0 && (snd_cs4231_in(codec, CS4231_TEST_INIT) & CS4231_CALIB_IN_PROGRESS) == 0; timeout--)
 		udelay(10);
-	if ((snd_cs4231_in(codec, CS4231_TEST_INIT) & CS4231_CALIB_IN_PROGRESS) == 0) {
+	if ((snd_cs4231_in(codec, CS4231_TEST_INIT) & CS4231_CALIB_IN_PROGRESS) == 0)
 		snd_printd("cs4231_mce_down - auto calibration time out (1)\n");
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
-		return;
-	}
 #if 0
 	printk("(2) timeout = %i, jiffies = %li\n", timeout, jiffies);
 #endif
 	time = HZ / 4;
 	while (snd_cs4231_in(codec, CS4231_TEST_INIT) & CS4231_CALIB_IN_PROGRESS) {
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
-		if (time <= 0) {
+		if (time-- < 0) {
 			snd_printk("cs4231_mce_down - auto calibration time out (2)\n");
 			return;
 		}
-		set_current_state(TASK_INTERRUPTIBLE);
-		time = schedule_timeout(time);
+		if (busywait)
+			mdelay(1);
+		else {
+			set_current_state(TASK_INTERRUPTIBLE);
+			time = schedule_timeout(1);
+		}
 		spin_lock_irqsave(&codec->reg_lock, flags);
 	}
 #if 0
@@ -338,11 +336,16 @@ void snd_cs4231_mce_down(cs4231_t * codec)
 	time = HZ / 10;
 	while (inb(CS4231P(codec, REGSEL)) & CS4231_INIT) {
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
-		if (time <= 0) {
+		if (time-- < 0) {
 			snd_printk("cs4231_mce_down - auto calibration time out (3)\n");
 			return;
 		}
-		set_current_state(TASK_INTERRUPTIBLE);		
+		if (busywait)
+			mdelay(1);
+		else {
+			set_current_state(TASK_INTERRUPTIBLE);		
+			time = schedule_timeout(1);
+		}
 		time = schedule_timeout(time);
 		spin_lock_irqsave(&codec->reg_lock, flags);
 	}
@@ -353,6 +356,11 @@ void snd_cs4231_mce_down(cs4231_t * codec)
 #endif
 }
 
+void snd_cs4231_mce_down(cs4231_t * codec)
+{
+	__snd_cs4231_mce_down(codec, 0); /* use schedule_timeout */
+}
+
 static unsigned int snd_cs4231_get_count(unsigned char format, unsigned int size)
 {
 	switch (format & 0xe0) {
@@ -1218,7 +1226,7 @@ static int snd_cs4231_playback_open(void * private_data,
 	if (runtime->hw == NULL)
 		return -ENOMEM;
 	memcpy(runtime->hw, &snd_cs4231_playback, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 
 	snd_pcm_set_sync(subchn);
 	snd_pcm_set_mixer(subchn, codec->mixer->device, codec->me_playback);
@@ -1250,7 +1258,7 @@ static int snd_cs4231_capture_open(void *private_data,
 	if (runtime->hw == NULL)
 		return -ENOMEM;
 	memcpy(runtime->hw, &snd_cs4231_capture, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 
 	snd_pcm_set_sync(subchn);
 	snd_pcm_set_mixer(subchn, codec->mixer->device, codec->me_capture);
@@ -1289,7 +1297,7 @@ static int snd_cs4231_capture_close(void *private_data,
 	return 0;
 }
 
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
 
 static void snd_cs4231_suspend(cs4231_t * codec)
 {
@@ -1306,7 +1314,6 @@ static void snd_cs4231_resume(cs4231_t * codec)
 {
 	int reg;
 	unsigned long flags;
-	int timeout;
 	
 	snd_cs4231_mce_up(codec);
 	spin_lock_irqsave(&codec->reg_lock, flags);
@@ -1320,28 +1327,7 @@ static void snd_cs4231_resume(cs4231_t * codec)
 		}
 	}
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
-#if 0
-	snd_cs4231_mce_down(codec);
-#else
-	/* The following is a workaround to avoid freeze after resume on TP600E.
-	   This is the first half of copy of snd_cs4231_mce_down(), but doesn't
-	   include rescheduling.  -- iwai
-	   */
-	spin_lock_irqsave(&codec->reg_lock, flags);
-	snd_cs4231_busy_wait(codec);
-	codec->mce_bit &= ~CS4231_MCE;
-	timeout = inb(CS4231P(codec, REGSEL));
-	outb(codec->mce_bit | (timeout & 0x1f), CS4231P(codec, REGSEL));
-	if (timeout == 0x80)
-		snd_printk("snd_cs4231_down [0x%lx]: serious init problem - codec still busy\n", codec->port);
-	if ((timeout & CS4231_MCE) == 0 ||
-	    !(codec->hardware & (CS4231_HW_CS4231_MASK | CS4231_HW_CS4232_MASK))) {
-		spin_unlock_irqrestore(&codec->reg_lock, flags);
-		return;
-	}
-	snd_cs4231_busy_wait(codec);
-	return;
-#endif
+	__snd_cs4231_mce_down(codec, 1);  /* don't reschedule */
 }
 
 static int snd_cs4231_pm_callback(struct pm_dev *dev, pm_request_t rqst, void *data)
@@ -1361,12 +1347,12 @@ static int snd_cs4231_pm_callback(struct pm_dev *dev, pm_request_t rqst, void *d
 	return 0;
 }
 
-#endif /* CONFIG_APM */
+#endif /* CONFIG_PM */
 
 static void snd_cs4231_free(void *private_data)
 {
 	cs4231_t *codec = snd_magic_cast(cs4231_t, private_data, );
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
 	if (codec->pm_dev)
 		pm_unregister(codec->pm_dev);
 #endif
@@ -1486,7 +1472,7 @@ int snd_cs4231_new_pcm(snd_card_t * card, int device,
 	memcpy(&timer->hw, &snd_cs4231_timer, sizeof(snd_cs4231_timer));
 	codec->timer = timer;
 
-#ifdef CONFIG_APM
+#ifdef CONFIG_PM
 	codec->suspend = snd_cs4231_suspend;
 	codec->resume = snd_cs4231_resume;
 	codec->pm_dev = pm_register(PM_ISA_DEV, 0, snd_cs4231_pm_callback);
@@ -2366,3 +2352,4 @@ static void __exit alsa_cs4231_exit(void)
 
 module_init(alsa_cs4231_init)
 module_exit(alsa_cs4231_exit)
+MODULE_LICENSE("GPL");
