@@ -450,6 +450,7 @@ static int snd_es1688_capture_prepare(void *private_data,
 	unsigned int size = snd_pcm_lib_transfer_size(subchn);
 	unsigned int count = snd_pcm_lib_transfer_fragment(subchn);
 
+	codec->dma_size = size;
 	spin_lock_irqsave(&codec->reg_lock, flags);
 	snd_es1688_reset(codec);
 	snd_es1688_set_rate(codec, runtime->format.rate);
@@ -665,6 +666,9 @@ int snd_es1688_new_pcm(snd_card_t * card, int device,
 	codec->pcm = pcm;
 	codec->card = pcm->card;
 	codec->port = port;
+	mpu_port &= ~0x000f;
+	if (mpu_port < 0x300 || mpu_port > 0x330)
+		mpu_port = 0;
 	codec->mpu_port = mpu_port;
 	codec->irqptr = irqptr;
 	codec->irq = irqptr->irq;
@@ -1287,3 +1291,4 @@ static void __exit alsa_es1688_exit(void)
 
 module_init(alsa_es1688_init)
 module_exit(alsa_es1688_exit)
+MODULE_LICENSE("GPL");
