@@ -113,7 +113,7 @@ static int snd_es18xx_dsp_get_byte(es18xx_t * codec)
         for(i = MILLISECOND/10; i; i--)
                 if (inb(codec->port + 0x0C) & 0x40)
                         return inb(codec->port + 0x0A);
-        snd_printk("es18xx get byte failed: 0x%x = 0x%x!!!\n", codec->port + 0x0A, inb(codec->port + 0x0A));
+        snd_printk("es18xx get byte failed: 0x%lx = 0x%x!!!\n", codec->port + 0x0A, inb(codec->port + 0x0A));
         return -ENODEV;
 }
 
@@ -359,7 +359,7 @@ static int snd_es18xx_initialize(es18xx_t * codec)
 			irqmask = 3;
 			break;
 		default:
-			snd_printk("es18xx: invalid irq %i\n", codec->irq);
+			snd_printk("es18xx: invalid irq %ld\n", codec->irq);
 			return -ENODEV;
 		}
 		switch (codec->dma1) {
@@ -373,7 +373,7 @@ static int snd_es18xx_initialize(es18xx_t * codec)
 			dma1mask = 3;
 			break;
 		default:
-			snd_printk("es18xx: invalid dma1 %i\n", codec->dma1);
+			snd_printk("es18xx: invalid dma1 %ld\n", codec->dma1);
 			return -ENODEV;
 		}
 		switch (codec->dma2) {
@@ -390,7 +390,7 @@ static int snd_es18xx_initialize(es18xx_t * codec)
 			dma2mask = 3;
 			break;
 		default:
-			snd_printk("es18xx: invalid dma2 %i\n", codec->dma2);
+			snd_printk("es18xx: invalid dma2 %ld\n", codec->dma2);
 			return -ENODEV;
 		}
 
@@ -453,7 +453,7 @@ static int snd_es18xx_identify(es18xx_t * codec)
 
 	/* reset */
 	if (snd_es18xx_reset(codec) < 0) {
-                snd_printk("snd_es18xx_reset at 0x%x failed!!!\n", codec->port);
+                snd_printk("snd_es18xx_reset at 0x%lx failed!!!\n", codec->port);
 		return -ENODEV;
 	}
 
@@ -510,7 +510,7 @@ static int snd_es18xx_identify(es18xx_t * codec)
 static int snd_es18xx_probe(es18xx_t *codec)
 {
 	if (snd_es18xx_identify(codec) < 0) {
-                snd_printk("[0x%x] ESS chip not found\n", codec->port);
+                snd_printk("[0x%lx] ESS chip not found\n", codec->port);
                 return -ENODEV;
 	}
 
@@ -534,12 +534,12 @@ static int snd_es18xx_probe(es18xx_t *codec)
 		codec->caps = ES18XX_PCM2 | ES18XX_RECMIX | ES18XX_AUXB | ES18XX_DUPLEX_SAME | ES18XX_HWV;
 		break;
 	default:
-                snd_printk("[0x%x] unsupported chip ES%x\n",
+                snd_printk("[0x%lx] unsupported chip ES%x\n",
                            codec->port, codec->version);
                 return -ENODEV;
         }
 
-        snd_printd("[0x%x] ESS%x chip found\n", codec->port, codec->version);
+        snd_printd("[0x%lx] ESS%x chip found\n", codec->port, codec->version);
 
         return snd_es18xx_initialize(codec);
 }
@@ -1117,9 +1117,9 @@ static void snd_es18xx_free(void *private_data)
 }
 
 int snd_es18xx_new_device(snd_card_t * card,
-                          unsigned short port,
-                          unsigned short mpu_port,
-                          unsigned short fm_port,
+                          unsigned long port,
+                          unsigned long mpu_port,
+                          unsigned long fm_port,
                           snd_irq_t * irqptr,
                           snd_dma_t * dma1ptr,
                           snd_dma_t * dma2ptr,
@@ -2209,3 +2209,4 @@ static void __exit alsa_es18xx_exit(void)
 
 module_init(alsa_es18xx_init)
 module_exit(alsa_es18xx_exit)
+MODULE_LICENSE("GPL");
