@@ -99,8 +99,8 @@ MODULE_PARM(ramcheck_time,"i");
 MODULE_PARM_DESC(ramcheck_time, "how many seconds to wait for the RAM test");
 MODULE_PARM(osrun_time,"i");
 MODULE_PARM_DESC(osrun_time, "how many seconds to wait for the ICS2115 OS");
-
-#endif MODULE_PARM
+MODULE_LICENSE("GPL");
+#endif /* MODULE_PARM */
 
 /*
  *	This sucks, hopefully it'll get standardised
@@ -108,6 +108,10 @@ MODULE_PARM_DESC(osrun_time, "how many seconds to wait for the ICS2115 OS");
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,2,18) && LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0)
 #define loops_per_sec loops_per_jiffy*HZ
+#elif LINUX_VERSION_CODE == KERNEL_VERSION(2,4,0) && defined(I_DIRTY_PAGES) /* linux/fs.h */
+#define loops_per_sec loops_per_jiffy*HZ
+#elif LINUX_VERSION_CODE > KERNEL_VERSION(2,4,0)
+#define loops_per_sec loops_per_jiffy*HZ
 #endif
  
 #if defined(__alpha__) || defined(__powerpc__)
@@ -137,7 +141,7 @@ MODULE_PARM_DESC(osrun_time, "how many seconds to wait for the ICS2115 OS");
        }
 #else
 #define DPRINT(cond, format, args...)
-#endif WF_DEBUG
+#endif /* WF_DEBUG */
 
 #define LOGNAME "WaveFront: "
 
@@ -1995,7 +1999,7 @@ wavefront_reset_to_cleanliness (snd_wavefront_t *dev)
 #define __KERNEL_SYSCALLS__
 #include <linux/fs.h>
 #include <linux/mm.h>
-#include <linux/malloc.h>
+#include <linux/slab.h>
 #include <linux/unistd.h>
 #include <asm/uaccess.h>
 
