@@ -121,8 +121,17 @@ static void snd_wavefront_midi_output_write(snd_wavefront_card_t *card)
 	   the MIDI interface while we're outputting stuff.  See
 	   snd_wavefront_midi_{enable,disable}_virtual () for the
 	   other half of this.  
+
+	   The first loop attempts to flush any data from the
+	   current output device, and then the second 
+	   emits the switch byte (if necessary), and starts
+	   outputting data for the output device currently in use.
 	*/
 
+	if (midi->rmidi[midi->output_mpu] == NULL) {
+		goto __second;
+	}
+
 	while (max > 0) {
 
 		/* XXX fix me - no hard timing loops allowed! */
@@ -162,6 +171,10 @@ static void snd_wavefront_midi_output_write(snd_wavefront_card_t *card)
 
       __second:
 
+	if (midi->rmidi[!midi->output_mpu] == NULL) {
+		return;
+	}
+
 	while (max > 0) {
 
 		/* XXX fix me - no hard timing loops allowed! */
@@ -180,7 +193,7 @@ static void snd_wavefront_midi_output_write(snd_wavefront_card_t *card)
 			spin_unlock_irqrestore (&midi->virtual, flags);
 			return;
 		}
-		if (snd_rawmidi_transmit_empty(midi->rmidi[midi->output_mpu]))
+		if (snd_rawmidi_transmit_empty(midi->rmidi[mpu]))
 			goto __timer;
 		if (output_ready (midi)) {
 			if (mpu != midi->output_mpu) {
@@ -188,7 +201,7 @@ static void snd_wavefront_midi_output_write(snd_wavefront_card_t *card)
 							WF_INTERNAL_SWITCH :
 							WF_EXTERNAL_SWITCH);
 				midi->output_mpu = mpu;
-			} else if (snd_rawmidi_transmit(midi->rmidi[midi->output_mpu], &midi_byte, 1) == 1) {
+			} else if (snd_rawmidi_transmit(midi->rmidi[mpu], &midi_byte, 1) == 1) {
 				if (!midi->isvirtual ||
 					(midi_byte != WF_INTERNAL_SWITCH &&
 					 midi_byte != WF_EXTERNAL_SWITCH))
@@ -200,7 +213,7 @@ static void snd_wavefront_midi_output_write(snd_wavefront_card_t *card)
 					if (--midi->istimer <= 0)
 						del_timer(&midi->timer);
 				}
-				midi->mode[midi->output_mpu] &= ~MPU401_MODE_OUTPUT_TRIGGER;
+				midi->mode[mpu] &= ~MPU401_MODE_OUTPUT_TRIGGER;
 				spin_unlock_irqrestore (&midi->virtual, flags);
 				return;
 			}
@@ -387,7 +400,8 @@ snd_wavefront_midi_interrupt (snd_wavefront_card_t *card)
 	unsigned long flags;
 	snd_wavefront_midi_t *midi;
 	static snd_rawmidi_t *rmidi = NULL;
-	int max = 128, mpu = internal_mpu;
+	static int mpu = external_mpu; 
+	int max = 128;
 	unsigned char byte;
 
 	midi = &card->wavefront.midi;
@@ -405,19 +419,22 @@ snd_wavefront_midi_interrupt (snd_wavefront_card_t *card)
 
 			if (midi->isvirtual) {				
 				if (byte == WF_EXTERNAL_SWITCH) {
+					rmidi = midi->rmidi[external_mpu];
 					mpu = external_mpu;
 				} else if (byte == WF_INTERNAL_SWITCH) { 
+					rmidi = midi->rmidi[internal_mpu];
 					mpu = internal_mpu;
 				} /* else just leave it as it is */
 			} else {
+				rmidi = midi->rmidi[internal_mpu];
 				mpu = internal_mpu;
 			}
-			
-			rmidi = midi->rmidi[mpu];
+
 			if (rmidi == NULL) {
 				spin_unlock_irqrestore (&midi->virtual, flags);
 				continue;
 			}
+
 			if (midi->mode[mpu] & MPU401_MODE_INPUT_TRIGGER) {
 				spin_unlock_irqrestore (&midi->virtual, flags);
 				snd_rawmidi_receive(rmidi, &byte, 1);
