@@ -434,7 +434,7 @@ int snd_als4000_playback_open(void *private_data, snd_pcm_subchn_t * subchn)
 	runtime->hw = (snd_pcm_hardware_t *) snd_kmalloc(sizeof(*runtime->hw), GFP_KERNEL);
 	if (runtime->hw == NULL) return -ENOMEM;
 	memcpy(runtime->hw, &snd_als4000_playback, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 	snd_pcm_set_mixer(subchn, codec->kmixer->device, 
 			  codec->mixer.me_playback);
 	runtime->private_data = codec;
@@ -462,7 +462,7 @@ int snd_als4000_capture_open(void *private_data, snd_pcm_subchn_t * subchn)
 	runtime->hw = (snd_pcm_hardware_t *) snd_kmalloc(sizeof(*runtime->hw), GFP_KERNEL);
 	if (runtime->hw == NULL) return -ENOMEM;
 	memcpy(runtime->hw, &snd_als4000_capture, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 	snd_pcm_set_mixer(subchn, codec->kmixer->device, 
 			  codec->mixer.me_capture);
 	runtime->private_data = codec;
@@ -562,7 +562,6 @@ static void snd_als4000dsp_free(void *private_data)
 int snd_als4000dsp_new_pcm(snd_card_t * card,
 			   int device,
 			   unsigned long gcr_port,
-			   unsigned long sb_port,
 			   snd_irq_t * irqptr,
 			   snd_dma_t * dmaptr,
 			   snd_rawmidi_t *rmidi,
@@ -584,7 +583,7 @@ int snd_als4000dsp_new_pcm(snd_card_t * card,
 	codec->playback_format = 0;
 	codec->capture_format = 0;
 	codec->gcr_port = gcr_port;
-	codec->sb_port = sb_port;
+	codec->sb_port = gcr_port + 0x10;
 	codec->irqptr = irqptr;
 	codec->dmaptr = dmaptr;
 	codec->rmidi = rmidi;
