@@ -1409,7 +1409,11 @@ int snd_ensoniq_create(snd_card_t * card,
 	if ((ensoniq->subsystem_vendor_id == 0x107b &&
 	     ensoniq->subsystem_device_id == 0x2150) ||	/* Gateway Solo 2150 */
 	    (ensoniq->subsystem_vendor_id == 0x13bd &&
-	     ensoniq->subsystem_device_id == 0x100c))   /* EV1938 on Mebius PC-MJ100V */
+	     ensoniq->subsystem_device_id == 0x100c) || /* EV1938 on Mebius PC-MJ100V */
+	    (ensoniq->subsystem_vendor_id == 0x1102 &&
+	     ensoniq->subsystem_device_id == 0x5938) || /* Targa Xtender300 */
+	    (ensoniq->subsystem_vendor_id == 0x1102 &&
+	     ensoniq->subsystem_device_id == 0x8938))	/* IPC Topnote G notebook */
 		ensoniq->ctrl |= ES_1371_GPIO_OUT(1);	/* turn amplifier on */
 	/* initialize the chips */
 	outl(ensoniq->ctrl, ES_REG(ensoniq, CONTROL));
@@ -1774,3 +1778,4 @@ static void __exit alsa_ens137x_exit(void)
 
 module_init(alsa_ens137x_init)
 module_exit(alsa_ens137x_exit)
+MODULE_LICENSE("GPL");
