@@ -229,7 +229,7 @@ static void snd_ice1712_delta_set_spdif_out(ice1712_t *ice, snd_pcm_subchn_t *su
 		if (val & (1 << idx))
 			tmp |= 0x08;
 		else
-			tmp &= 0x08;
+			tmp &= ~0x08;
 		tmp |= 0x04;
 		snd_ice1712_write(ice, ICE1712_IREG_GPIO_DATA, tmp);
 		udelay(100);
@@ -835,7 +835,7 @@ static int snd_ice1712_capture_pro_open(void *private_data,
 		return -ENOMEM;
 	}
 	subchn->runtime->dig_mask = dig_mask;
-	subchn->runtime->dig_mask_free = _snd_kfree;
+	subchn->runtime->dig_mask_free = (snd_kfree_type)_snd_kfree;
 	dig_mask->dig_status[0] = 0xff;
 	dig_mask->dig_status[1] = 0xff;
 	dig_mask->dig_status[3] = 0xff;
@@ -1921,3 +1921,4 @@ static void __exit alsa_ice1712_exit(void)
 
 module_init(alsa_ice1712_init)
 module_exit(alsa_ice1712_exit)
+MODULE_LICENSE("GPL");
