@@ -347,8 +347,8 @@ static int __init snd_rme9652_initialize_memory (rme9652_t * rme9652)
 	cb = (u_long) snd_rme9652_get_buffer ();
 	pb = (u_long) snd_rme9652_get_buffer ();
 #else
-	cb = snd_malloc_pages (RME9652_DMA_AREA_BYTES(rme9652), &pg, 1);
-	pb = snd_malloc_pages (RME9652_DMA_AREA_BYTES(rme9652), &pg, 1);
+	cb = snd_malloc_pages (RME9652_DMA_AREA_BYTES(rme9652), &pg, GFP_KERNEL|GFP_DMA);
+	pb = snd_malloc_pages (RME9652_DMA_AREA_BYTES(rme9652), &pg, GFP_KERNEL|GFP_DMA);
 #endif	
 
 	if (cb == 0 || pb == 0) {
@@ -2451,3 +2451,4 @@ module_init(alsa_rme9652_init)
 module_exit(alsa_rme9652_exit)
 
 
+MODULE_LICENSE("GPL");
