@@ -1673,7 +1673,7 @@ static int snd_trident_spdif_open(void *private_data,
 		snd_pcm_dma_free(subchn);
 		return -ENOMEM;
 	}
-	runtime->dig_mask_free = _snd_kfree;
+	runtime->dig_mask_free = (snd_kfree_type)_snd_kfree;
 	spin_lock_irqsave(&trident->reg_lock, flags);
 	tpcm = snd_trident_alloc_voice(trident, SND_TRIDENT_VOICE_TYPE_PCM, 0, 0);
 	if (tpcm == NULL) {
@@ -3092,3 +3092,4 @@ static void __exit alsa_trident_exit(void)
 
 module_init(alsa_trident_init)
 module_exit(alsa_trident_exit)
+MODULE_LICENSE("GPL");
