@@ -174,6 +174,15 @@ snd_emu8000_sample_new(void *private_data, snd_sf_sample_t *sp,
 		offset++;
 		write_word(emu, &dram_offset, s);
 
+		/* we may take too long time in this loop.
+		 * so give controls back to kernel if needed.
+		 */
+		if (current->need_resched) {
+			if (current->state != TASK_RUNNING)
+				set_current_state(TASK_RUNNING);
+			schedule();
+		}
+
 		if (i == sp->v.loopend &&
 		    (sp->v.mode_flags & (SND_SFNT_SAMPLE_BIDIR_LOOP|SND_SFNT_SAMPLE_REVERSE_LOOP)))
 		{
