@@ -44,7 +44,7 @@ void snd_sb8dsp_midi_interrupt(snd_rawmidi_t * rmidi)
 	}
 	while (max-- > 0) {
 		spin_lock_irqsave(&codec->midi_input_lock, flags);
-		if (SBP(codec, DATA_AVAIL) & 0x80) {
+		if (inb(SBP(codec, DATA_AVAIL)) & 0x80) {
 			byte = inb(SBP(codec, READ));
 			spin_unlock_irqrestore(&codec->midi_input_lock, flags);
 			snd_rawmidi_receive(rmidi, &byte, 1);
