@@ -441,7 +441,7 @@ int snd_sb16_playback_open(void *private_data, snd_pcm_subchn_t * subchn)
 	if (runtime->hw == NULL)
 		return -ENOMEM;
 	memcpy(runtime->hw, &snd_sb16_playback, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 	snd_pcm_set_mixer(subchn, codec->kmixer->device, codec->mixer.me_playback);
 	runtime->private_data = codec;
 	if (codec->dma16ptr &&
@@ -500,7 +500,7 @@ int snd_sb16_capture_open(void *private_data, snd_pcm_subchn_t * subchn)
 	if (runtime->hw == NULL)
 		return -ENOMEM;
 	memcpy(runtime->hw, &snd_sb16_capture, sizeof(*runtime->hw));
-	runtime->hw_free = _snd_kfree;
+	runtime->hw_free = (snd_kfree_type)_snd_kfree;
 	snd_pcm_set_mixer(subchn, codec->kmixer->device, codec->mixer.me_playback);
 	runtime->private_data = codec;
 	if (codec->dma16ptr &&
