@@ -32,7 +32,8 @@
 MODULE_AUTHOR("Uros Bizjak <uros@kss-loka.si>");
 MODULE_DESCRIPTION("ALSA driver for SB16 Creative Signal Processor\n\
 classes: {sound}");
-#endif MODULE_PARM
+MODULE_LICENSE("GPL");
+#endif /* MODULE_PARM */
 
 #ifdef SND_LITTLE_ENDIAN
 #define CSP_HDR_VALUE(a,b,c,d)	((a) | ((b)<<8) | ((c)<<16) | ((d)<<24))
@@ -40,8 +41,8 @@ classes: {sound}");
 #define LE_INT(v)		(v)
 #else
 #define CSP_HDR_VALUE(a,b,c,d)	((d) | ((c)<<8) | ((b)<<16) | ((a)<<24))
-#define LE_SHORT(v)		bswap_16(v)
-#define LE_INT(v)		bswap_32(v)
+#define LE_SHORT(v)		le16_to_cpu(v)
+#define LE_INT(v)		le32_to_cpu(v)
 #endif
 
 #define RIFF_HEADER	CSP_HDR_VALUE('R', 'I', 'F', 'F')
@@ -663,6 +664,7 @@ static int snd_sb_csp_load(snd_sb_csp_t * p, const unsigned char *buf, int size,
 
 	if (load_flags & SND_SB_CSP_LOAD_INITBLOCK) {
 		/* some codecs (FastSpeech) take some time to initialize */
+		status = 0;  /* to make gcc happy */
 		for (i = 10; i; i--) {
 			snd_sb16dsp_command(p->codec, 0x03);
 			status = snd_sb16dsp_get_byte(p->codec);
