@@ -51,7 +51,7 @@ int snd_sb8dsp_get_byte(sbdsp_t * codec)
 	for (i = 1000; i; i--)
 		if (inb(SBP(codec, DATA_AVAIL)) & 0x80)
 			return inb(SBP(codec, READ));
-	snd_printd(__FUNCTION__ " failed: 0x%x = 0x%x!!!\n", SBP(codec, DATA_AVAIL), inb(SBP(codec, DATA_AVAIL)));
+	snd_printd(__FUNCTION__ " failed: 0x%lx = 0x%x!!!\n", SBP(codec, DATA_AVAIL), inb(SBP(codec, DATA_AVAIL)));
 	return -ENODEV;
 }
 
@@ -65,7 +65,7 @@ int snd_sb8dsp_reset(sbdsp_t * codec)
 	udelay(30);
 	for (i = 0; i < 1000 && !(inb(SBP(codec, DATA_AVAIL)) & 0x80); i++);
 	if (inb(SBP(codec, READ)) != 0xaa) {
-		snd_printd(__FUNCTION__ ": failed at 0x%x!!!\n", codec->port);
+		snd_printd(__FUNCTION__ ": failed at 0x%lx!!!\n", codec->port);
 		return -ENODEV;
 	}
 	return 0;
@@ -112,7 +112,7 @@ int snd_sb8dsp_probe(snd_pcm_t * pcm)
 
 	spin_lock_irqsave(&codec->reg_lock, flags);
 	if (snd_sb8dsp_reset(codec) < 0) {
-		snd_printdd("SB: [0x%x] reset failed... 0x%x\n", codec->port, inb(SBP(codec, READ)));
+		snd_printdd("SB: [0x%lx] reset failed... 0x%x\n", codec->port, inb(SBP(codec, READ)));
 		spin_unlock_irqrestore(&codec->reg_lock, flags);
 		return -ENODEV;
 	}
@@ -122,7 +122,7 @@ int snd_sb8dsp_probe(snd_pcm_t * pcm)
 	if (version < 0)
 		return -ENODEV;
 
-	snd_printdd("SB [0x%x]: DSP chip found, version = %i.%i\n", codec->port, version >> 8, version & 0xff);
+	snd_printdd("SB [0x%lx]: DSP chip found, version = %i.%i\n", codec->port, version >> 8, version & 0xff);
 
 	hw = SB_HW_AUTO;
 	switch (version >> 8) {
@@ -136,10 +136,10 @@ int snd_sb8dsp_probe(snd_pcm_t * pcm)
 		hw = SB_HW_PRO;
 		break;
 	case 4:
-		snd_printk("SB [0x%x]: DSP chip version %i.%i is not supported by the SB8 code\n", codec->port, version >> 8, version & 0xff);
+		snd_printk("SB [0x%lx]: DSP chip version %i.%i is not supported by the SB8 code\n", codec->port, version >> 8, version & 0xff);
 		break;
 	default:
-		snd_printk("SB [0x%x]: unknown DSP chip version %i.%i\n", codec->port, version >> 8, version & 0xff);
+		snd_printk("SB [0x%lx]: unknown DSP chip version %i.%i\n", codec->port, version >> 8, version & 0xff);
 		return -ENODEV;
 	}
 	switch (codec->hardware = hw) {
@@ -172,7 +172,7 @@ void snd_sb8dsp_free(void *private_data)
 
 int snd_sb8dsp_new_pcm(snd_card_t * card,
 		       int device,
-		       unsigned short port,
+		       unsigned long port,
 		       snd_irq_t * irqptr,
 		       snd_dma_t * dma8ptr,
 		       unsigned short hardware,
@@ -248,3 +248,4 @@ static void __exit alsa_sb8_exit(void)
 
 module_init(alsa_sb8_init)
 module_exit(alsa_sb8_exit)
+MODULE_LICENSE("GPL");
