@@ -47,7 +47,7 @@
 #include <linux/errno.h>
 #include <linux/ioport.h>
 #include <linux/string.h>
-#include <linux/malloc.h>
+#include <linux/slab.h>
 #include <linux/delay.h>
 #include <linux/proc_fs.h>
 #include <asm/io.h>
@@ -64,6 +64,13 @@
 #include "isapnp.h"
 #endif
 
+#ifdef CONFIG_ALL_PPC
+#include <asm/processor.h>
+#define isPReP (_machine == _MACH_prep)
+#else
+#define isPReP 1
+#endif
+
 #if 0
 #define ISAPNP_REGION_OK
 #endif
@@ -2189,7 +2196,7 @@ __initfunc(int isapnp_init(void))
 	struct isapnp_card *card;
 	struct isapnp_dev *dev;
 
-	if (isapnp_disable) {
+	if (isapnp_disable || !isPReP) {
 		isapnp_detected = 0;
 		printk("isapnp: ISA Plug & Play support disabled\n");
 		return 0;
